@@ -39,6 +39,12 @@ from .fetchers import NUMetadatasFetcher
 from .fetchers import NUEgressACLTemplatesFetcher
 
 
+from .fetchers import NUDomainFIPAclTemplatesFetcher
+
+
+from .fetchers import NUFloatingIPACLTemplatesFetcher
+
+
 from .fetchers import NUGlobalMetadatasFetcher
 
 
@@ -81,7 +87,7 @@ class NUDomainTemplate(NURESTObject):
     """ Represents a DomainTemplate in the VSD
 
         Notes:
-            Domains in VSD are created from domain templates. This object provides the definition of the DomainTemplate.
+            Domains in VSD are created from domain templates. This object provides the definition of the Domain Template.
     """
 
     __rest_name__ = "domaintemplate"
@@ -98,6 +104,8 @@ class NUDomainTemplate(NURESTObject):
     
     CONST_ENCRYPTION_DISABLED = "DISABLED"
     
+    CONST_DPI_ENABLED = "ENABLED"
+    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
     CONST_ENCRYPTION_ENABLED = "ENABLED"
@@ -108,6 +116,8 @@ class NUDomainTemplate(NURESTObject):
     
     CONST_MULTICAST_INHERITED = "INHERITED"
     
+    CONST_DPI_DISABLED = "DISABLED"
+    
     CONST_POLICY_CHANGE_STATUS_APPLIED = "APPLIED"
     
     
@@ -129,23 +139,29 @@ class NUDomainTemplate(NURESTObject):
 
         # Read/Write Attributes
         
+        self._dpi = None
         self._name = None
         self._last_updated_by = None
         self._description = None
         self._encryption = None
         self._entity_scope = None
         self._policy_change_status = None
+        self._associated_bgp_profile_id = None
         self._associated_multicast_channel_map_id = None
+        self._associated_pat_mapper_id = None
         self._multicast = None
         self._external_id = None
         
+        self.expose_attribute(local_name="dpi", remote_name="DPI", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="encryption", remote_name="encryption", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="policy_change_status", remote_name="policyChangeStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'APPLIED', u'DISCARDED', u'STARTED'])
+        self.expose_attribute(local_name="associated_bgp_profile_id", remote_name="associatedBGPProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_multicast_channel_map_id", remote_name="associatedMulticastChannelMapID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_pat_mapper_id", remote_name="associatedPATMapperID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
@@ -165,6 +181,12 @@ class NUDomainTemplate(NURESTObject):
         self.egress_acl_templates = NUEgressACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.domain_fip_acl_templates = NUDomainFIPAclTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.floating_ipacl_templates = NUFloatingIPACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -205,6 +227,33 @@ class NUDomainTemplate(NURESTObject):
 
     # Properties
     
+    @property
+    def dpi(self):
+        """ Get dpi value.
+
+            Notes:
+                determines whether or not Deep packet inspection is enabled
+
+                
+                This attribute is named `DPI` in VSD API.
+                
+        """
+        return self._dpi
+
+    @dpi.setter
+    def dpi(self, value):
+        """ Set dpi value.
+
+            Notes:
+                determines whether or not Deep packet inspection is enabled
+
+                
+                This attribute is named `DPI` in VSD API.
+                
+        """
+        self._dpi = value
+
+    
     @property
     def name(self):
         """ Get name value.
@@ -355,6 +404,33 @@ class NUDomainTemplate(NURESTObject):
         self._policy_change_status = value
 
     
+    @property
+    def associated_bgp_profile_id(self):
+        """ Get associated_bgp_profile_id value.
+
+            Notes:
+                The ID of the associated BGP profile
+
+                
+                This attribute is named `associatedBGPProfileID` in VSD API.
+                
+        """
+        return self._associated_bgp_profile_id
+
+    @associated_bgp_profile_id.setter
+    def associated_bgp_profile_id(self, value):
+        """ Set associated_bgp_profile_id value.
+
+            Notes:
+                The ID of the associated BGP profile
+
+                
+                This attribute is named `associatedBGPProfileID` in VSD API.
+                
+        """
+        self._associated_bgp_profile_id = value
+
+    
     @property
     def associated_multicast_channel_map_id(self):
         """ Get associated_multicast_channel_map_id value.
@@ -382,6 +458,33 @@ class NUDomainTemplate(NURESTObject):
         self._associated_multicast_channel_map_id = value
 
     
+    @property
+    def associated_pat_mapper_id(self):
+        """ Get associated_pat_mapper_id value.
+
+            Notes:
+                The ID of the PatMapper entity to which this domain-template is associated to.
+
+                
+                This attribute is named `associatedPATMapperID` in VSD API.
+                
+        """
+        return self._associated_pat_mapper_id
+
+    @associated_pat_mapper_id.setter
+    def associated_pat_mapper_id(self, value):
+        """ Set associated_pat_mapper_id value.
+
+            Notes:
+                The ID of the PatMapper entity to which this domain-template is associated to.
+
+                
+                This attribute is named `associatedPATMapperID` in VSD API.
+                
+        """
+        self._associated_pat_mapper_id = value
+
+    
     @property
     def multicast(self):
         """ Get multicast value.
