@@ -33,6 +33,9 @@ from .fetchers import NUL2DomainsFetcher
 from .fetchers import NUL2DomainTemplatesFetcher
 
 
+from .fetchers import NUL7applicationsignaturesFetcher
+
+
 from .fetchers import NURateLimitersFetcher
 
 
@@ -51,6 +54,9 @@ from .fetchers import NULDAPConfigurationsFetcher
 from .fetchers import NURedundancyGroupsFetcher
 
 
+from .fetchers import NUPerformanceMonitorsFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -60,30 +66,63 @@ from .fetchers import NUMetadataTagsFetcher
 from .fetchers import NUNetworkMacroGroupsFetcher
 
 
+from .fetchers import NUNetworkPerformanceMeasurementsFetcher
+
+
 from .fetchers import NUKeyServerMonitorsFetcher
 
 
+from .fetchers import NUZFBRequestsFetcher
+
+
+from .fetchers import NUBGPProfilesFetcher
+
+
 from .fetchers import NUEgressQOSPoliciesFetcher
 
 
 from .fetchers import NUSharedNetworkResourcesFetcher
 
 
+from .fetchers import NUFirewallAclsFetcher
+
+
+from .fetchers import NUFirewallRulesFetcher
+
+
+from .fetchers import NUIKECertificatesFetcher
+
+
+from .fetchers import NUIKEEncryptionprofilesFetcher
+
+
+from .fetchers import NUIKEGatewaysFetcher
+
+
+from .fetchers import NUIKEGatewayProfilesFetcher
+
+
+from .fetchers import NUIKEPSKsFetcher
+
+
 from .fetchers import NUAlarmsFetcher
 
 
+from .fetchers import NUAllAlarmsFetcher
+
+
 from .fetchers import NUGlobalMetadatasFetcher
 
 
 from .fetchers import NUVMsFetcher
 
 
-from .fetchers import NUInfrastructurePortProfilesFetcher
-
-
 from .fetchers import NUEnterpriseNetworksFetcher
 
 
+from .fetchers import NUEnterpriseSecuritiesFetcher
+
+
 from .fetchers import NUJobsFetcher
 
 
@@ -93,7 +132,16 @@ from .fetchers import NUDomainsFetcher
 from .fetchers import NUDomainTemplatesFetcher
 
 
-from .fetchers import NUAppsFetcher
+from .fetchers import NUContainersFetcher
+
+
+from .fetchers import NURoutingPoliciesFetcher
+
+
+from .fetchers import NUApplicationsFetcher
+
+
+from .fetchers import NUApplicationperformancemanagementsFetcher
 
 
 from .fetchers import NUApplicationServicesFetcher
@@ -117,12 +165,21 @@ from .fetchers import NUNSGatewaysFetcher
 from .fetchers import NUNSGatewayTemplatesFetcher
 
 
+from .fetchers import NUNSGGroupsFetcher
+
+
 from .fetchers import NUNSRedundantGatewayGroupsFetcher
 
 
+from .fetchers import NUPublicNetworkMacrosFetcher
+
+
 from .fetchers import NUMultiCastListsFetcher
 
 
+from .fetchers import NUAvatarsFetcher
+
+
 from .fetchers import NUEventLogsFetcher
 
 
@@ -138,7 +195,7 @@ class NUEnterprise(NURESTObject):
     """ Represents a Enterprise in the VSD
 
         Notes:
-            Definition of the enterprise object. This is the top level object that represents an organization.
+            Definition of the enterprise object. This is the top level object that represents an enterprise.
     """
 
     __rest_name__ = "enterprise"
@@ -200,21 +257,25 @@ class NUEnterprise(NURESTObject):
         
         self._ldap_authorization_enabled = None
         self._ldap_enabled = None
+        self._bgp_enabled = None
         self._dhcp_lease_interval = None
         self._name = None
         self._last_updated_by = None
         self._receive_multi_cast_list_id = None
         self._send_multi_cast_list_id = None
         self._description = None
+        self._dictionary_version = None
         self._allow_advanced_qos_configuration = None
         self._allow_gateway_management = None
         self._allow_trusted_forwarding_class = None
         self._allowed_forwarding_classes = None
         self._floating_ips_quota = None
         self._floating_ips_used = None
+        self._enable_application_performance_management = None
         self._encryption_management_mode = None
         self._enterprise_profile_id = None
         self._entity_scope = None
+        self._local_as = None
         self._associated_enterprise_security_id = None
         self._associated_group_key_encryption_profile_id = None
         self._associated_key_server_monitor_id = None
@@ -225,21 +286,25 @@ class NUEnterprise(NURESTObject):
         
         self.expose_attribute(local_name="ldap_authorization_enabled", remote_name="LDAPAuthorizationEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="ldap_enabled", remote_name="LDAPEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="bgp_enabled", remote_name="BGPEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dhcp_lease_interval", remote_name="DHCPLeaseInterval", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="receive_multi_cast_list_id", remote_name="receiveMultiCastListID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="send_multi_cast_list_id", remote_name="sendMultiCastListID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="dictionary_version", remote_name="dictionaryVersion", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_advanced_qos_configuration", remote_name="allowAdvancedQOSConfiguration", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_gateway_management", remote_name="allowGatewayManagement", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_trusted_forwarding_class", remote_name="allowTrustedForwardingClass", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allowed_forwarding_classes", remote_name="allowedForwardingClasses", attribute_type=list, is_required=False, is_unique=False, choices=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'NONE'])
         self.expose_attribute(local_name="floating_ips_quota", remote_name="floatingIPsQuota", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="floating_ips_used", remote_name="floatingIPsUsed", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="enable_application_performance_management", remote_name="enableApplicationPerformanceManagement", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="encryption_management_mode", remote_name="encryptionManagementMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'MANAGED'])
         self.expose_attribute(local_name="enterprise_profile_id", remote_name="enterpriseProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="local_as", remote_name="localAS", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_enterprise_security_id", remote_name="associatedEnterpriseSecurityID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_group_key_encryption_profile_id", remote_name="associatedGroupKeyEncryptionProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_key_server_monitor_id", remote_name="associatedKeyServerMonitorID", attribute_type=str, is_required=False, is_unique=False)
@@ -258,6 +323,9 @@ class NUEnterprise(NURESTObject):
         self.l2_domain_templates = NUL2DomainTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.l7applicationsignatures = NUL7applicationsignaturesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.rate_limiters = NURateLimitersFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -276,6 +344,9 @@ class NUEnterprise(NURESTObject):
         self.redundancy_groups = NURedundancyGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.performance_monitors = NUPerformanceMonitorsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -285,30 +356,63 @@ class NUEnterprise(NURESTObject):
         self.network_macro_groups = NUNetworkMacroGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.network_performance_measurements = NUNetworkPerformanceMeasurementsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.key_server_monitors = NUKeyServerMonitorsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.zfb_requests = NUZFBRequestsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.bgp_profiles = NUBGPProfilesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.egress_qos_policies = NUEgressQOSPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.shared_network_resources = NUSharedNetworkResourcesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.firewall_acls = NUFirewallAclsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.firewall_rules = NUFirewallRulesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.ike_certificates = NUIKECertificatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.ike_encryptionprofiles = NUIKEEncryptionprofilesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.ike_gateways = NUIKEGatewaysFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.ike_gateway_profiles = NUIKEGatewayProfilesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.ikepsks = NUIKEPSKsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.alarms = NUAlarmsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.all_alarms = NUAllAlarmsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.vms = NUVMsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.infrastructure_port_profiles = NUInfrastructurePortProfilesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.enterprise_networks = NUEnterpriseNetworksFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.enterprise_securities = NUEnterpriseSecuritiesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -318,7 +422,16 @@ class NUEnterprise(NURESTObject):
         self.domain_templates = NUDomainTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.apps = NUAppsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        self.containers = NUContainersFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.routing_policies = NURoutingPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.applications = NUApplicationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.applicationperformancemanagements = NUApplicationperformancemanagementsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.application_services = NUApplicationServicesFetcher.fetcher_with_object(parent_object=self, relationship="child")
@@ -342,12 +455,21 @@ class NUEnterprise(NURESTObject):
         self.ns_gateway_templates = NUNSGatewayTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.nsg_groups = NUNSGGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.ns_redundant_gateway_groups = NUNSRedundantGatewayGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.public_network_macros = NUPublicNetworkMacrosFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.multi_cast_lists = NUMultiCastListsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.avatars = NUAvatarsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.event_logs = NUEventLogsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -415,6 +537,33 @@ class NUEnterprise(NURESTObject):
         self._ldap_enabled = value
 
     
+    @property
+    def bgp_enabled(self):
+        """ Get bgp_enabled value.
+
+            Notes:
+                Read only flag to display if BGP is enabled for this enterprise
+
+                
+                This attribute is named `BGPEnabled` in VSD API.
+                
+        """
+        return self._bgp_enabled
+
+    @bgp_enabled.setter
+    def bgp_enabled(self, value):
+        """ Set bgp_enabled value.
+
+            Notes:
+                Read only flag to display if BGP is enabled for this enterprise
+
+                
+                This attribute is named `BGPEnabled` in VSD API.
+                
+        """
+        self._bgp_enabled = value
+
+    
     @property
     def dhcp_lease_interval(self):
         """ Get dhcp_lease_interval value.
@@ -569,6 +718,33 @@ class NUEnterprise(NURESTObject):
         self._description = value
 
     
+    @property
+    def dictionary_version(self):
+        """ Get dictionary_version value.
+
+            Notes:
+                L7 Application Type version
+
+                
+                This attribute is named `dictionaryVersion` in VSD API.
+                
+        """
+        return self._dictionary_version
+
+    @dictionary_version.setter
+    def dictionary_version(self, value):
+        """ Set dictionary_version value.
+
+            Notes:
+                L7 Application Type version
+
+                
+                This attribute is named `dictionaryVersion` in VSD API.
+                
+        """
+        self._dictionary_version = value
+
+    
     @property
     def allow_advanced_qos_configuration(self):
         """ Get allow_advanced_qos_configuration value.
@@ -731,6 +907,33 @@ class NUEnterprise(NURESTObject):
         self._floating_ips_used = value
 
     
+    @property
+    def enable_application_performance_management(self):
+        """ Get enable_application_performance_management value.
+
+            Notes:
+                This flag indicates if the DPI can be enabled for this enterpriseenterprise/organization.
+
+                
+                This attribute is named `enableApplicationPerformanceManagement` in VSD API.
+                
+        """
+        return self._enable_application_performance_management
+
+    @enable_application_performance_management.setter
+    def enable_application_performance_management(self, value):
+        """ Set enable_application_performance_management value.
+
+            Notes:
+                This flag indicates if the DPI can be enabled for this enterpriseenterprise/organization.
+
+                
+                This attribute is named `enableApplicationPerformanceManagement` in VSD API.
+                
+        """
+        self._enable_application_performance_management = value
+
+    
     @property
     def encryption_management_mode(self):
         """ Get encryption_management_mode value.
@@ -812,6 +1015,33 @@ class NUEnterprise(NURESTObject):
         self._entity_scope = value
 
     
+    @property
+    def local_as(self):
+        """ Get local_as value.
+
+            Notes:
+                Local autonomous system for the enterprise
+
+                
+                This attribute is named `localAS` in VSD API.
+                
+        """
+        return self._local_as
+
+    @local_as.setter
+    def local_as(self, value):
+        """ Set local_as value.
+
+            Notes:
+                Local autonomous system for the enterprise
+
+                
+                This attribute is named `localAS` in VSD API.
+                
+        """
+        self._local_as = value
+
+    
     @property
     def associated_enterprise_security_id(self):
         """ Get associated_enterprise_security_id value.
