@@ -110,6 +110,7 @@ class NUIngressACLTemplate(NURESTObject):
         self._priority_type = None
         self._assoc_acl_template_id = None
         self._associated_live_entity_id = None
+        self._auto_generate_priority = None
         self._external_id = None
         
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
@@ -126,6 +127,7 @@ class NUIngressACLTemplate(NURESTObject):
         self.expose_attribute(local_name="priority_type", remote_name="priorityType", attribute_type=str, is_required=False, is_unique=False, choices=[u'BOTTOM', u'NONE', u'TOP'])
         self.expose_attribute(local_name="assoc_acl_template_id", remote_name="assocAclTemplateId", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_live_entity_id", remote_name="associatedLiveEntityID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="auto_generate_priority", remote_name="autoGeneratePriority", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -519,6 +521,33 @@ class NUIngressACLTemplate(NURESTObject):
         self._associated_live_entity_id = value
 
     
+    @property
+    def auto_generate_priority(self):
+        """ Get auto_generate_priority value.
+
+            Notes:
+                This option affects how ACL entry priorities are generated when not specified. If "false", the priority is generated by incrementing the current highest priority by 100. If "true", a random priority will be generated, which is advised when creating many entries concurrently without specifying the priority. This will cause the ACL entry to be randomly placed in the existing list of ACL entries. Therefore it is advised to only enable this when allow rules are being created.
+
+                
+                This attribute is named `autoGeneratePriority` in VSD API.
+                
+        """
+        return self._auto_generate_priority
+
+    @auto_generate_priority.setter
+    def auto_generate_priority(self, value):
+        """ Set auto_generate_priority value.
+
+            Notes:
+                This option affects how ACL entry priorities are generated when not specified. If "false", the priority is generated by incrementing the current highest priority by 100. If "true", a random priority will be generated, which is advised when creating many entries concurrently without specifying the priority. This will cause the ACL entry to be randomly placed in the existing list of ACL entries. Therefore it is advised to only enable this when allow rules are being created.
+
+                
+                This attribute is named `autoGeneratePriority` in VSD API.
+                
+        """
+        self._auto_generate_priority = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
