@@ -30,12 +30,6 @@
 from .fetchers import NUMetadatasFetcher
 
 
-from .fetchers import NUKeyServerMonitorEncryptedSeedsFetcher
-
-
-from .fetchers import NUKeyServerMonitorEncryptedSEKsFetcher
-
-
 from .fetchers import NUGlobalMetadatasFetcher
 
 from bambou import NURESTObject
@@ -45,7 +39,7 @@ class NUKeyServerMonitorSEK(NURESTObject):
     """ Represents a KeyServerMonitorSEK in the VSD
 
         Notes:
-            Represents a Keyserver Monitor SEK Snapshot
+            Represents a Keyserver Monitor SEK Snapshot.
     """
 
     __rest_name__ = "keyservermonitorsek"
@@ -114,12 +108,6 @@ class NUKeyServerMonitorSEK(NURESTObject):
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.key_server_monitor_encrypted_seeds = NUKeyServerMonitorEncryptedSeedsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.key_server_monitor_encrypted_seks = NUKeyServerMonitorEncryptedSEKsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
 
