@@ -27,6 +27,9 @@
 
 
 
+from .fetchers import NUGatewaySecuritiesFetcher
+
+
 from .fetchers import NUPATNATPoolsFetcher
 
 
@@ -54,15 +57,24 @@ from .fetchers import NUJobsFetcher
 from .fetchers import NULocationsFetcher
 
 
+from .fetchers import NUMonitorscopesFetcher
+
+
 from .fetchers import NUBootstrapsFetcher
 
 
 from .fetchers import NUBootstrapActivationsFetcher
 
 
+from .fetchers import NUNSGInfosFetcher
+
+
 from .fetchers import NUNSPortsFetcher
 
 
+from .fetchers import NUSubnetsFetcher
+
+
 from .fetchers import NUEventLogsFetcher
 
 from bambou import NURESTObject
@@ -72,7 +84,7 @@ class NUNSGateway(NURESTObject):
     """ Represents a NSGateway in the VSD
 
         Notes:
-            Represents Network Service Gateway object.
+            Represents a Network Service Gateway.
     """
 
     __rest_name__ = "nsgateway"
@@ -81,22 +93,38 @@ class NUNSGateway(NURESTObject):
     
     ## Constants
     
+    CONST_FAMILY_NSG_E = "NSG_E"
+    
+    CONST_INHERITED_SSH_SERVICE_STATE_ENABLED = "ENABLED"
+    
     CONST_CONFIGURATION_STATUS_FAILURE = "FAILURE"
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
+    CONST_PERSONALITY_NSGDUC = "NSGDUC"
+    
+    CONST_FAMILY_NSG_V = "NSG_V"
+    
+    CONST_DERIVED_SSH_SERVICE_STATE_INSTANCE_DISABLED = "INSTANCE_DISABLED"
+    
     CONST_BOOTSTRAP_STATUS_ACTIVE = "ACTIVE"
     
     CONST_CONFIGURATION_RELOAD_STATE_PENDING = "PENDING"
     
+    CONST_SSH_SERVICE_DISABLED = "DISABLED"
+    
     CONST_PERSONALITY_OTHER = "OTHER"
     
+    CONST_SSH_SERVICE_ENABLED = "ENABLED"
+    
     CONST_BOOTSTRAP_STATUS_NOTIFICATION_APP_REQ_ACK = "NOTIFICATION_APP_REQ_ACK"
     
     CONST_PERSONALITY_NSG = "NSG"
     
     CONST_PERMITTED_ACTION_EXTEND = "EXTEND"
     
+    CONST_DERIVED_SSH_SERVICE_STATE_INHERITED_ENABLED = "INHERITED_ENABLED"
+    
     CONST_CONFIGURATION_STATUS_SUCCESS = "SUCCESS"
     
     CONST_PERMITTED_ACTION_INSTANTIATE = "INSTANTIATE"
@@ -107,9 +135,13 @@ class NUNSGateway(NURESTObject):
     
     CONST_BOOTSTRAP_STATUS_CERTIFICATE_SIGNED = "CERTIFICATE_SIGNED"
     
-    CONST_BOOTSTRAP_STATUS_NOTIFICATION_APP_REQ_SENT = "NOTIFICATION_APP_REQ_SENT"
+    CONST_DERIVED_SSH_SERVICE_STATE_INSTANCE_ENABLED = "INSTANCE_ENABLED"
     
-    CONST_CONFIGURATION_STATUS_UNKNOWN = "UNKNOWN"
+    CONST_FAMILY_ANY = "ANY"
+    
+    CONST_TPM_STATUS_DISABLED = "DISABLED"
+    
+    CONST_CONFIGURATION_RELOAD_STATE_APPLIED = "APPLIED"
     
     CONST_PERSONALITY_HARDWARE_VTEP = "HARDWARE_VTEP"
     
@@ -121,20 +153,38 @@ class NUNSGateway(NURESTObject):
     
     CONST_PERMITTED_ACTION_USE = "USE"
     
+    CONST_DERIVED_SSH_SERVICE_STATE_INHERITED_DISABLED = "INHERITED_DISABLED"
+    
+    CONST_TPM_STATUS_ENABLED_NOT_OPERATIONAL = "ENABLED_NOT_OPERATIONAL"
+    
+    CONST_TPM_STATUS_UNKNOWN = "UNKNOWN"
+    
     CONST_PERSONALITY_VRSG = "VRSG"
     
+    CONST_BOOTSTRAP_STATUS_NOTIFICATION_APP_REQ_SENT = "NOTIFICATION_APP_REQ_SENT"
+    
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
     CONST_PERMITTED_ACTION_ALL = "ALL"
     
     CONST_PERMITTED_ACTION_DEPLOY = "DEPLOY"
     
-    CONST_CONFIGURATION_RELOAD_STATE_APPLIED = "APPLIED"
+    CONST_DERIVED_SSH_SERVICE_STATE_UNKNOWN = "UNKNOWN"
+    
+    CONST_INHERITED_SSH_SERVICE_STATE_DISABLED = "DISABLED"
+    
+    CONST_TPM_STATUS_ENABLED_OPERATIONAL = "ENABLED_OPERATIONAL"
+    
+    CONST_SSH_SERVICE_INHERITED = "INHERITED"
+    
+    CONST_CONFIGURATION_STATUS_UNKNOWN = "UNKNOWN"
     
     CONST_CONFIGURATION_RELOAD_STATE_SENT = "SENT"
     
     CONST_BOOTSTRAP_STATUS_INACTIVE = "INACTIVE"
     
+    CONST_PERSONALITY_NSGBR = "NSGBR"
+    
     
 
     def __init__(self, **kwargs):
@@ -154,16 +204,31 @@ class NUNSGateway(NURESTObject):
 
         # Read/Write Attributes
         
+        self._mac_address = None
         self._nat_traversal_enabled = None
+        self._tcpmss_enabled = None
+        self._tcp_maximum_segment_size = None
+        self._sku = None
+        self._tpm_status = None
+        self._cpu_type = None
+        self._nsg_version = None
+        self._ssh_service = None
+        self._uuid = None
         self._name = None
+        self._family = None
+        self._last_configuration_reload_timestamp = None
         self._last_updated_by = None
         self._datapath_id = None
         self._redundancy_group_id = None
         self._template_id = None
         self._pending = None
+        self._serial_number = None
+        self._derived_ssh_service_state = None
         self._permitted_action = None
         self._personality = None
         self._description = None
+        self._libraries = None
+        self._inherited_ssh_service_state = None
         self._enterprise_id = None
         self._entity_scope = None
         self._location_id = None
@@ -171,22 +236,40 @@ class NUNSGateway(NURESTObject):
         self._configuration_status = None
         self._bootstrap_id = None
         self._bootstrap_status = None
+        self._operation_mode = None
+        self._operation_status = None
         self._associated_gateway_security_id = None
         self._associated_gateway_security_profile_id = None
+        self._associated_nsg_info_id = None
         self._auto_disc_gateway_id = None
         self._external_id = None
         self._system_id = None
         
+        self.expose_attribute(local_name="mac_address", remote_name="MACAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nat_traversal_enabled", remote_name="NATTraversalEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="tcpmss_enabled", remote_name="TCPMSSEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="tcp_maximum_segment_size", remote_name="TCPMaximumSegmentSize", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="sku", remote_name="SKU", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="tpm_status", remote_name="TPMStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED_NOT_OPERATIONAL', u'ENABLED_OPERATIONAL', u'UNKNOWN'])
+        self.expose_attribute(local_name="cpu_type", remote_name="CPUType", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="nsg_version", remote_name="NSGVersion", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ssh_service", remote_name="SSHService", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
+        self.expose_attribute(local_name="uuid", remote_name="UUID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="family", remote_name="family", attribute_type=str, is_required=False, is_unique=False, choices=[u'ANY', u'NSG_E', u'NSG_V'])
+        self.expose_attribute(local_name="last_configuration_reload_timestamp", remote_name="lastConfigurationReloadTimestamp", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="datapath_id", remote_name="datapathID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="redundancy_group_id", remote_name="redundancyGroupID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="template_id", remote_name="templateID", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="pending", remote_name="pending", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="serial_number", remote_name="serialNumber", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="derived_ssh_service_state", remote_name="derivedSSHServiceState", attribute_type=str, is_required=False, is_unique=False, choices=[u'INHERITED_DISABLED', u'INHERITED_ENABLED', u'INSTANCE_DISABLED', u'INSTANCE_ENABLED', u'UNKNOWN'])
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
-        self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'DC7X50', u'HARDWARE_VTEP', u'NSG', u'OTHER', u'VRSG', u'VSA', u'VSG'])
+        self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'DC7X50', u'HARDWARE_VTEP', u'NSG', u'NSGBR', u'NSGDUC', u'OTHER', u'VRSG', u'VSA', u'VSG'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="libraries", remote_name="libraries", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="inherited_ssh_service_state", remote_name="inheritedSSHServiceState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="enterprise_id", remote_name="enterpriseID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="location_id", remote_name="locationID", attribute_type=str, is_required=False, is_unique=False)
@@ -194,8 +277,11 @@ class NUNSGateway(NURESTObject):
         self.expose_attribute(local_name="configuration_status", remote_name="configurationStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'FAILURE', u'SUCCESS', u'UNKNOWN'])
         self.expose_attribute(local_name="bootstrap_id", remote_name="bootstrapID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="bootstrap_status", remote_name="bootstrapStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'ACTIVE', u'CERTIFICATE_SIGNED', u'INACTIVE', u'NOTIFICATION_APP_REQ_ACK', u'NOTIFICATION_APP_REQ_SENT'])
+        self.expose_attribute(local_name="operation_mode", remote_name="operationMode", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="operation_status", remote_name="operationStatus", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_gateway_security_id", remote_name="associatedGatewaySecurityID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_gateway_security_profile_id", remote_name="associatedGatewaySecurityProfileID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_nsg_info_id", remote_name="associatedNSGInfoID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="auto_disc_gateway_id", remote_name="autoDiscGatewayID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         self.expose_attribute(local_name="system_id", remote_name="systemID", attribute_type=str, is_required=False, is_unique=False)
@@ -204,7 +290,10 @@ class NUNSGateway(NURESTObject):
         # Fetchers
         
         
-        self.patnat_pools = NUPATNATPoolsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        self.gateway_securities = NUGatewaySecuritiesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.patnat_pools = NUPATNATPoolsFetcher.fetcher_with_object(parent_object=self, relationship="member")
         
         
         self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
@@ -231,15 +320,24 @@ class NUNSGateway(NURESTObject):
         self.locations = NULocationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.monitorscopes = NUMonitorscopesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.bootstraps = NUBootstrapsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.bootstrap_activations = NUBootstrapActivationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.nsg_infos = NUNSGInfosFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.ns_ports = NUNSPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.subnets = NUSubnetsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.event_logs = NUEventLogsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
 
@@ -247,12 +345,39 @@ class NUNSGateway(NURESTObject):
 
     # Properties
     
+    @property
+    def mac_address(self):
+        """ Get mac_address value.
+
+            Notes:
+                MAC Address of the NSG
+
+                
+                This attribute is named `MACAddress` in VSD API.
+                
+        """
+        return self._mac_address
+
+    @mac_address.setter
+    def mac_address(self, value):
+        """ Set mac_address value.
+
+            Notes:
+                MAC Address of the NSG
+
+                
+                This attribute is named `MACAddress` in VSD API.
+                
+        """
+        self._mac_address = value
+
+    
     @property
     def nat_traversal_enabled(self):
         """ Get nat_traversal_enabled value.
 
             Notes:
-                Boolean value that states if the NSG instance is in a network that is behind a NAT device and will use NAT Traversal procedures to talk to other NSGs and the Internet.
+                This attribute is deprecated in version 4.0.
 
                 
                 This attribute is named `NATTraversalEnabled` in VSD API.
@@ -265,7 +390,7 @@ class NUNSGateway(NURESTObject):
         """ Set nat_traversal_enabled value.
 
             Notes:
-                Boolean value that states if the NSG instance is in a network that is behind a NAT device and will use NAT Traversal procedures to talk to other NSGs and the Internet.
+                This attribute is deprecated in version 4.0.
 
                 
                 This attribute is named `NATTraversalEnabled` in VSD API.
@@ -274,6 +399,222 @@ class NUNSGateway(NURESTObject):
         self._nat_traversal_enabled = value
 
     
+    @property
+    def tcpmss_enabled(self):
+        """ Get tcpmss_enabled value.
+
+            Notes:
+                Boolean flag to indicate whether MSS on TCP is enabled or not
+
+                
+                This attribute is named `TCPMSSEnabled` in VSD API.
+                
+        """
+        return self._tcpmss_enabled
+
+    @tcpmss_enabled.setter
+    def tcpmss_enabled(self, value):
+        """ Set tcpmss_enabled value.
+
+            Notes:
+                Boolean flag to indicate whether MSS on TCP is enabled or not
+
+                
+                This attribute is named `TCPMSSEnabled` in VSD API.
+                
+        """
+        self._tcpmss_enabled = value
+
+    
+    @property
+    def tcp_maximum_segment_size(self):
+        """ Get tcp_maximum_segment_size value.
+
+            Notes:
+                Maximum Segment Size for TCP(min = 576, max = 7812).
+
+                
+                This attribute is named `TCPMaximumSegmentSize` in VSD API.
+                
+        """
+        return self._tcp_maximum_segment_size
+
+    @tcp_maximum_segment_size.setter
+    def tcp_maximum_segment_size(self, value):
+        """ Set tcp_maximum_segment_size value.
+
+            Notes:
+                Maximum Segment Size for TCP(min = 576, max = 7812).
+
+                
+                This attribute is named `TCPMaximumSegmentSize` in VSD API.
+                
+        """
+        self._tcp_maximum_segment_size = value
+
+    
+    @property
+    def sku(self):
+        """ Get sku value.
+
+            Notes:
+                The part number of the NSG
+
+                
+                This attribute is named `SKU` in VSD API.
+                
+        """
+        return self._sku
+
+    @sku.setter
+    def sku(self, value):
+        """ Set sku value.
+
+            Notes:
+                The part number of the NSG
+
+                
+                This attribute is named `SKU` in VSD API.
+                
+        """
+        self._sku = value
+
+    
+    @property
+    def tpm_status(self):
+        """ Get tpm_status value.
+
+            Notes:
+                TPM Status of the NSG based on the information received by the device during bootstrapping or upgrade.
+
+                
+                This attribute is named `TPMStatus` in VSD API.
+                
+        """
+        return self._tpm_status
+
+    @tpm_status.setter
+    def tpm_status(self, value):
+        """ Set tpm_status value.
+
+            Notes:
+                TPM Status of the NSG based on the information received by the device during bootstrapping or upgrade.
+
+                
+                This attribute is named `TPMStatus` in VSD API.
+                
+        """
+        self._tpm_status = value
+
+    
+    @property
+    def cpu_type(self):
+        """ Get cpu_type value.
+
+            Notes:
+                The NSG Processor Type
+
+                
+                This attribute is named `CPUType` in VSD API.
+                
+        """
+        return self._cpu_type
+
+    @cpu_type.setter
+    def cpu_type(self, value):
+        """ Set cpu_type value.
+
+            Notes:
+                The NSG Processor Type
+
+                
+                This attribute is named `CPUType` in VSD API.
+                
+        """
+        self._cpu_type = value
+
+    
+    @property
+    def nsg_version(self):
+        """ Get nsg_version value.
+
+            Notes:
+                The NSG Version
+
+                
+                This attribute is named `NSGVersion` in VSD API.
+                
+        """
+        return self._nsg_version
+
+    @nsg_version.setter
+    def nsg_version(self, value):
+        """ Set nsg_version value.
+
+            Notes:
+                The NSG Version
+
+                
+                This attribute is named `NSGVersion` in VSD API.
+                
+        """
+        self._nsg_version = value
+
+    
+    @property
+    def ssh_service(self):
+        """ Get ssh_service value.
+
+            Notes:
+                Indicates if SSH Service is enabled/disabled on a NSG. The value configured for this attribute is used only when instanceSSHOverride is allowed on the associated Gateway Template.
+
+                
+                This attribute is named `SSHService` in VSD API.
+                
+        """
+        return self._ssh_service
+
+    @ssh_service.setter
+    def ssh_service(self, value):
+        """ Set ssh_service value.
+
+            Notes:
+                Indicates if SSH Service is enabled/disabled on a NSG. The value configured for this attribute is used only when instanceSSHOverride is allowed on the associated Gateway Template.
+
+                
+                This attribute is named `SSHService` in VSD API.
+                
+        """
+        self._ssh_service = value
+
+    
+    @property
+    def uuid(self):
+        """ Get uuid value.
+
+            Notes:
+                The Redhat UUID of the NSG
+
+                
+                This attribute is named `UUID` in VSD API.
+                
+        """
+        return self._uuid
+
+    @uuid.setter
+    def uuid(self, value):
+        """ Set uuid value.
+
+            Notes:
+                The Redhat UUID of the NSG
+
+                
+                This attribute is named `UUID` in VSD API.
+                
+        """
+        self._uuid = value
+
+    
     @property
     def name(self):
         """ Get name value.
@@ -297,6 +638,56 @@ class NUNSGateway(NURESTObject):
         self._name = value
 
     
+    @property
+    def family(self):
+        """ Get family value.
+
+            Notes:
+                The NSG Type
+
+                
+        """
+        return self._family
+
+    @family.setter
+    def family(self, value):
+        """ Set family value.
+
+            Notes:
+                The NSG Type
+
+                
+        """
+        self._family = value
+
+    
+    @property
+    def last_configuration_reload_timestamp(self):
+        """ Get last_configuration_reload_timestamp value.
+
+            Notes:
+                Time stamp of the last known configuration update of the NSG.  This timestamp gets updated when a bootstrap is successful or when a configuration reload request triggered by VSD is successful.
+
+                
+                This attribute is named `lastConfigurationReloadTimestamp` in VSD API.
+                
+        """
+        return self._last_configuration_reload_timestamp
+
+    @last_configuration_reload_timestamp.setter
+    def last_configuration_reload_timestamp(self, value):
+        """ Set last_configuration_reload_timestamp value.
+
+            Notes:
+                Time stamp of the last known configuration update of the NSG.  This timestamp gets updated when a bootstrap is successful or when a configuration reload request triggered by VSD is successful.
+
+                
+                This attribute is named `lastConfigurationReloadTimestamp` in VSD API.
+                
+        """
+        self._last_configuration_reload_timestamp = value
+
+    
     @property
     def last_updated_by(self):
         """ Get last_updated_by value.
@@ -428,6 +819,60 @@ class NUNSGateway(NURESTObject):
         self._pending = value
 
     
+    @property
+    def serial_number(self):
+        """ Get serial_number value.
+
+            Notes:
+                The NSG's serial number
+
+                
+                This attribute is named `serialNumber` in VSD API.
+                
+        """
+        return self._serial_number
+
+    @serial_number.setter
+    def serial_number(self, value):
+        """ Set serial_number value.
+
+            Notes:
+                The NSG's serial number
+
+                
+                This attribute is named `serialNumber` in VSD API.
+                
+        """
+        self._serial_number = value
+
+    
+    @property
+    def derived_ssh_service_state(self):
+        """ Get derived_ssh_service_state value.
+
+            Notes:
+                Indicates the SSH Service state on a NSG. This value is derived based on the SSHService configuration on the NSG and the associated Gateway Template.
+
+                
+                This attribute is named `derivedSSHServiceState` in VSD API.
+                
+        """
+        return self._derived_ssh_service_state
+
+    @derived_ssh_service_state.setter
+    def derived_ssh_service_state(self, value):
+        """ Set derived_ssh_service_state value.
+
+            Notes:
+                Indicates the SSH Service state on a NSG. This value is derived based on the SSHService configuration on the NSG and the associated Gateway Template.
+
+                
+                This attribute is named `derivedSSHServiceState` in VSD API.
+                
+        """
+        self._derived_ssh_service_state = value
+
+    
     @property
     def permitted_action(self):
         """ Get permitted_action value.
@@ -501,6 +946,56 @@ class NUNSGateway(NURESTObject):
         self._description = value
 
     
+    @property
+    def libraries(self):
+        """ Get libraries value.
+
+            Notes:
+                Transient representation of the same property on NSGInfo.
+
+                
+        """
+        return self._libraries
+
+    @libraries.setter
+    def libraries(self, value):
+        """ Set libraries value.
+
+            Notes:
+                Transient representation of the same property on NSGInfo.
+
+                
+        """
+        self._libraries = value
+
+    
+    @property
+    def inherited_ssh_service_state(self):
+        """ Get inherited_ssh_service_state value.
+
+            Notes:
+                Indicates the SSH Service state which is configured on the associated template instance.
+
+                
+                This attribute is named `inheritedSSHServiceState` in VSD API.
+                
+        """
+        return self._inherited_ssh_service_state
+
+    @inherited_ssh_service_state.setter
+    def inherited_ssh_service_state(self, value):
+        """ Set inherited_ssh_service_state value.
+
+            Notes:
+                Indicates the SSH Service state which is configured on the associated template instance.
+
+                
+                This attribute is named `inheritedSSHServiceState` in VSD API.
+                
+        """
+        self._inherited_ssh_service_state = value
+
+    
     @property
     def enterprise_id(self):
         """ Get enterprise_id value.
@@ -587,7 +1082,7 @@ class NUNSGateway(NURESTObject):
         """ Get configuration_reload_state value.
 
             Notes:
-                
+                None
 
                 
                 This attribute is named `configurationReloadState` in VSD API.
@@ -600,7 +1095,7 @@ class NUNSGateway(NURESTObject):
         """ Set configuration_reload_state value.
 
             Notes:
-                
+                None
 
                 
                 This attribute is named `configurationReloadState` in VSD API.
@@ -614,7 +1109,7 @@ class NUNSGateway(NURESTObject):
         """ Get configuration_status value.
 
             Notes:
-                
+                None
 
                 
                 This attribute is named `configurationStatus` in VSD API.
@@ -627,7 +1122,7 @@ class NUNSGateway(NURESTObject):
         """ Set configuration_status value.
 
             Notes:
-                
+                None
 
                 
                 This attribute is named `configurationStatus` in VSD API.
@@ -690,6 +1185,60 @@ class NUNSGateway(NURESTObject):
         self._bootstrap_status = value
 
     
+    @property
+    def operation_mode(self):
+        """ Get operation_mode value.
+
+            Notes:
+                Operation mode of NSGateway
+
+                
+                This attribute is named `operationMode` in VSD API.
+                
+        """
+        return self._operation_mode
+
+    @operation_mode.setter
+    def operation_mode(self, value):
+        """ Set operation_mode value.
+
+            Notes:
+                Operation mode of NSGateway
+
+                
+                This attribute is named `operationMode` in VSD API.
+                
+        """
+        self._operation_mode = value
+
+    
+    @property
+    def operation_status(self):
+        """ Get operation_status value.
+
+            Notes:
+                Operation Status of NSGateway
+
+                
+                This attribute is named `operationStatus` in VSD API.
+                
+        """
+        return self._operation_status
+
+    @operation_status.setter
+    def operation_status(self, value):
+        """ Set operation_status value.
+
+            Notes:
+                Operation Status of NSGateway
+
+                
+                This attribute is named `operationStatus` in VSD API.
+                
+        """
+        self._operation_status = value
+
+    
     @property
     def associated_gateway_security_id(self):
         """ Get associated_gateway_security_id value.
@@ -744,6 +1293,33 @@ class NUNSGateway(NURESTObject):
         self._associated_gateway_security_profile_id = value
 
     
+    @property
+    def associated_nsg_info_id(self):
+        """ Get associated_nsg_info_id value.
+
+            Notes:
+                Readonly Id of the associated nsg info object
+
+                
+                This attribute is named `associatedNSGInfoID` in VSD API.
+                
+        """
+        return self._associated_nsg_info_id
+
+    @associated_nsg_info_id.setter
+    def associated_nsg_info_id(self, value):
+        """ Set associated_nsg_info_id value.
+
+            Notes:
+                Readonly Id of the associated nsg info object
+
+                
+                This attribute is named `associatedNSGInfoID` in VSD API.
+                
+        """
+        self._associated_nsg_info_id = value
+
+    
     @property
     def auto_disc_gateway_id(self):
         """ Get auto_disc_gateway_id value.
