@@ -27,6 +27,9 @@
 
 
 
+from .fetchers import NUPATIPEntriesFetcher
+
+
 from .fetchers import NUAddressRangesFetcher
 
 
@@ -54,7 +57,7 @@ class NUSharedNetworkResource(NURESTObject):
     """ Represents a SharedNetworkResource in the VSD
 
         Notes:
-            This defines shared infrastructure resources that are created by user with CSPROOT role. These resources can be used by all the enterprises in the data center for various purposes. Examples of  shared resources are public subnet, floating subnet, public L2 domain, etc.
+            This defines shared infrastructure resources that are created by user with CSPROOT role. These resources can be used by all the enterprises in the data center for various purposes. Examples of  shared resources are public subnet, floating subnet, public L2 domain.
     """
 
     __rest_name__ = "sharednetworkresource"
@@ -73,8 +76,12 @@ class NUSharedNetworkResource(NURESTObject):
     
     CONST_TYPE_UPLINK_SUBNET = "UPLINK_SUBNET"
     
+    CONST_USE_GLOBAL_MAC_ENABLED = "ENABLED"
+    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
+    CONST_USE_GLOBAL_MAC_DISABLED = "DISABLED"
+    
     CONST_PERMITTED_ACTION_TYPE_USE = "USE"
     
     CONST_PERMITTED_ACTION_TYPE_READ = "READ"
@@ -114,6 +121,7 @@ class NUSharedNetworkResource(NURESTObject):
         self._name = None
         self._last_updated_by = None
         self._gateway = None
+        self._gateway_mac_address = None
         self._access_restriction_enabled = None
         self._address = None
         self._permitted_action_type = None
@@ -129,7 +137,10 @@ class NUSharedNetworkResource(NURESTObject):
         self._uplink_interface_ip = None
         self._uplink_interface_mac = None
         self._uplink_vport_name = None
+        self._use_global_mac = None
+        self._associated_pat_mapper_id = None
         self._external_id = None
+        self._dynamic_pat_allocation_enabled = None
         self._type = None
         
         self.expose_attribute(local_name="ecmp_count", remote_name="ECMPCount", attribute_type=int, is_required=False, is_unique=False)
@@ -140,6 +151,7 @@ class NUSharedNetworkResource(NURESTObject):
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway", remote_name="gateway", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="gateway_mac_address", remote_name="gatewayMACAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="access_restriction_enabled", remote_name="accessRestrictionEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="permitted_action_type", remote_name="permittedActionType", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
@@ -155,13 +167,19 @@ class NUSharedNetworkResource(NURESTObject):
         self.expose_attribute(local_name="uplink_interface_ip", remote_name="uplinkInterfaceIP", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="uplink_interface_mac", remote_name="uplinkInterfaceMAC", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="uplink_vport_name", remote_name="uplinkVPortName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="use_global_mac", remote_name="useGlobalMAC", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
+        self.expose_attribute(local_name="associated_pat_mapper_id", remote_name="associatedPATMapperID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
+        self.expose_attribute(local_name="dynamic_pat_allocation_enabled", remote_name="dynamicPATAllocationEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=True, is_unique=False, choices=[u'FLOATING', u'L2DOMAIN', u'PUBLIC', u'UPLINK_SUBNET'])
         
 
         # Fetchers
         
         
+        self.patip_entries = NUPATIPEntriesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.address_ranges = NUAddressRangesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -395,6 +413,33 @@ class NUSharedNetworkResource(NURESTObject):
         self._gateway = value
 
     
+    @property
+    def gateway_mac_address(self):
+        """ Get gateway_mac_address value.
+
+            Notes:
+                MAC address for a public subnet or managed l2 domain
+
+                
+                This attribute is named `gatewayMACAddress` in VSD API.
+                
+        """
+        return self._gateway_mac_address
+
+    @gateway_mac_address.setter
+    def gateway_mac_address(self, value):
+        """ Set gateway_mac_address value.
+
+            Notes:
+                MAC address for a public subnet or managed l2 domain
+
+                
+                This attribute is named `gatewayMACAddress` in VSD API.
+                
+        """
+        self._gateway_mac_address = value
+
+    
     @property
     def access_restriction_enabled(self):
         """ Get access_restriction_enabled value.
@@ -784,6 +829,60 @@ class NUSharedNetworkResource(NURESTObject):
         self._uplink_vport_name = value
 
     
+    @property
+    def use_global_mac(self):
+        """ Get use_global_mac value.
+
+            Notes:
+                if this flag is enabled, the system configured globalMACAddress will be used as the gateway mac address
+
+                
+                This attribute is named `useGlobalMAC` in VSD API.
+                
+        """
+        return self._use_global_mac
+
+    @use_global_mac.setter
+    def use_global_mac(self, value):
+        """ Set use_global_mac value.
+
+            Notes:
+                if this flag is enabled, the system configured globalMACAddress will be used as the gateway mac address
+
+                
+                This attribute is named `useGlobalMAC` in VSD API.
+                
+        """
+        self._use_global_mac = value
+
+    
+    @property
+    def associated_pat_mapper_id(self):
+        """ Get associated_pat_mapper_id value.
+
+            Notes:
+                The ID of the PatMapper entity to which this pool is associated to.
+
+                
+                This attribute is named `associatedPATMapperID` in VSD API.
+                
+        """
+        return self._associated_pat_mapper_id
+
+    @associated_pat_mapper_id.setter
+    def associated_pat_mapper_id(self, value):
+        """ Set associated_pat_mapper_id value.
+
+            Notes:
+                The ID of the PatMapper entity to which this pool is associated to.
+
+                
+                This attribute is named `associatedPATMapperID` in VSD API.
+                
+        """
+        self._associated_pat_mapper_id = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
@@ -811,6 +910,33 @@ class NUSharedNetworkResource(NURESTObject):
         self._external_id = value
 
     
+    @property
+    def dynamic_pat_allocation_enabled(self):
+        """ Get dynamic_pat_allocation_enabled value.
+
+            Notes:
+                Indicates if PAT Mapping is enabled for the SharedNetworkResource or not
+
+                
+                This attribute is named `dynamicPATAllocationEnabled` in VSD API.
+                
+        """
+        return self._dynamic_pat_allocation_enabled
+
+    @dynamic_pat_allocation_enabled.setter
+    def dynamic_pat_allocation_enabled(self, value):
+        """ Set dynamic_pat_allocation_enabled value.
+
+            Notes:
+                Indicates if PAT Mapping is enabled for the SharedNetworkResource or not
+
+                
+                This attribute is named `dynamicPATAllocationEnabled` in VSD API.
+                
+        """
+        self._dynamic_pat_allocation_enabled = value
+
+    
     @property
     def type(self):
         """ Get type value.
