@@ -64,13 +64,11 @@ class NUApplicationperformancemanagement(NURESTObject):
         self._name = None
         self._read_only = None
         self._description = None
-        self._app_group_unique_id = None
         self._associated_performance_monitor_id = None
         
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="read_only", remote_name="readOnly", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="app_group_unique_id", remote_name="appGroupUniqueId", attribute_type=str, is_required=False, is_unique=True)
         self.expose_attribute(local_name="associated_performance_monitor_id", remote_name="associatedPerformanceMonitorID", attribute_type=str, is_required=False, is_unique=False)
         
 
@@ -157,33 +155,6 @@ class NUApplicationperformancemanagement(NURESTObject):
         self._description = value
 
     
-    @property
-    def app_group_unique_id(self):
-        """ Get app_group_unique_id value.
-
-            Notes:
-                2 byte unique ID generated by VSD to identify Application Group between OVS, nuage_dpi and perfd processes for proper functioning of AAR.
-
-                
-                This attribute is named `appGroupUniqueId` in VSD API.
-                
-        """
-        return self._app_group_unique_id
-
-    @app_group_unique_id.setter
-    def app_group_unique_id(self, value):
-        """ Set app_group_unique_id value.
-
-            Notes:
-                2 byte unique ID generated by VSD to identify Application Group between OVS, nuage_dpi and perfd processes for proper functioning of AAR.
-
-                
-                This attribute is named `appGroupUniqueId` in VSD API.
-                
-        """
-        self._app_group_unique_id = value
-
-    
     @property
     def associated_performance_monitor_id(self):
         """ Get associated_performance_monitor_id value.
