@@ -39,15 +39,36 @@ from .fetchers import NUPermissionsFetcher
 from .fetchers import NUMetadatasFetcher
 
 
+from .fetchers import NUNetworkPerformanceBindingsFetcher
+
+
+from .fetchers import NUPGExpressionsFetcher
+
+
 from .fetchers import NUEgressACLEntryTemplatesFetcher
 
 
 from .fetchers import NUEgressACLTemplatesFetcher
 
 
+from .fetchers import NUEgressAdvFwdTemplatesFetcher
+
+
+from .fetchers import NUDomainFIPAclTemplatesFetcher
+
+
+from .fetchers import NUFloatingIPACLTemplatesFetcher
+
+
 from .fetchers import NUDHCPOptionsFetcher
 
 
+from .fetchers import NULinksFetcher
+
+
+from .fetchers import NUFirewallAclsFetcher
+
+
 from .fetchers import NUFloatingIpsFetcher
 
 
@@ -60,6 +81,9 @@ from .fetchers import NUVMsFetcher
 from .fetchers import NUVMInterfacesFetcher
 
 
+from .fetchers import NUVNFDomainMappingsFetcher
+
+
 from .fetchers import NUIngressACLEntryTemplatesFetcher
 
 
@@ -87,12 +111,24 @@ from .fetchers import NUDomainTemplatesFetcher
 from .fetchers import NUZonesFetcher
 
 
+from .fetchers import NUContainersFetcher
+
+
+from .fetchers import NUContainerInterfacesFetcher
+
+
 from .fetchers import NUQOSsFetcher
 
 
 from .fetchers import NUHostInterfacesFetcher
 
 
+from .fetchers import NURoutingPoliciesFetcher
+
+
+from .fetchers import NUSPATSourcesPoolsFetcher
+
+
 from .fetchers import NUUplinkRDsFetcher
 
 
@@ -102,6 +138,9 @@ from .fetchers import NUVPNConnectionsFetcher
 from .fetchers import NUVPortsFetcher
 
 
+from .fetchers import NUApplicationperformancemanagementbindingsFetcher
+
+
 from .fetchers import NUBridgeInterfacesFetcher
 
 
@@ -122,9 +161,6 @@ from .fetchers import NUSubnetsFetcher
 
 from .fetchers import NUEventLogsFetcher
 
-
-from .fetchers import NUExternalAppServicesFetcher
-
 from bambou import NURESTObject
 
 
@@ -132,7 +168,7 @@ class NUDomain(NURESTObject):
     """ Represents a Domain in the VSD
 
         Notes:
-            This object is used to manipulate domain state. A domain corresponds to a distributed Virtual Router and Switch (dVRS).
+            This object is used to manipulate domain state. A domain corresponds to a distributed Virtual Router and Switch.
     """
 
     __rest_name__ = "domain"
@@ -143,22 +179,22 @@ class NUDomain(NURESTObject):
     
     CONST_PAT_ENABLED_DISABLED = "DISABLED"
     
-    CONST_PERMITTED_ACTION_ALL = "ALL"
+    CONST_ENCRYPTION_DISABLED = "DISABLED"
     
     CONST_PAT_ENABLED_INHERITED = "INHERITED"
     
-    CONST_UPLINK_PREFERENCE_SECONDARY_PRIMARY = "SECONDARY_PRIMARY"
-    
     CONST_UPLINK_PREFERENCE_PRIMARY_SECONDARY = "PRIMARY_SECONDARY"
     
     CONST_DHCP_BEHAVIOR_CONSUME = "CONSUME"
     
-    CONST_APPLICATION_DEPLOYMENT_POLICY_NONE = "NONE"
+    CONST_DPI_ENABLED = "ENABLED"
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
     CONST_POLICY_CHANGE_STATUS_DISCARDED = "DISCARDED"
     
+    CONST_DHCP_BEHAVIOR_UNDERLAY_RELAY = "UNDERLAY_RELAY"
+    
     CONST_UNDERLAY_ENABLED_ENABLED = "ENABLED"
     
     CONST_MAINTENANCE_MODE_DISABLED = "DISABLED"
@@ -173,15 +209,15 @@ class NUDomain(NURESTObject):
     
     CONST_PERMITTED_ACTION_INSTANTIATE = "INSTANTIATE"
     
+    CONST_DHCP_BEHAVIOR_OVERLAY_RELAY = "OVERLAY_RELAY"
+    
     CONST_UNDERLAY_ENABLED_INHERITED = "INHERITED"
     
     CONST_POLICY_CHANGE_STATUS_STARTED = "STARTED"
     
     CONST_PERMITTED_ACTION_READ = "READ"
     
-    CONST_DHCP_BEHAVIOR_RELAY = "RELAY"
-    
-    CONST_APPLICATION_DEPLOYMENT_POLICY_ZONE = "ZONE"
+    CONST_UPLINK_PREFERENCE_SECONDARY_PRIMARY = "SECONDARY_PRIMARY"
     
     CONST_PERMITTED_ACTION_USE = "USE"
     
@@ -191,6 +227,8 @@ class NUDomain(NURESTObject):
     
     CONST_MULTICAST_INHERITED = "INHERITED"
     
+    CONST_ADVERTISE_CRITERIA_HUB_ROUTES = "HUB_ROUTES"
+    
     CONST_UPLINK_PREFERENCE_SECONDARY = "SECONDARY"
     
     CONST_DHCP_BEHAVIOR_FLOOD = "FLOOD"
@@ -201,12 +239,14 @@ class NUDomain(NURESTObject):
     
     CONST_TUNNEL_TYPE_VXLAN = "VXLAN"
     
-    CONST_ENCRYPTION_DISABLED = "DISABLED"
+    CONST_PERMITTED_ACTION_ALL = "ALL"
     
     CONST_PERMITTED_ACTION_DEPLOY = "DEPLOY"
     
     CONST_UPLINK_PREFERENCE_PRIMARY = "PRIMARY"
     
+    CONST_DPI_DISABLED = "DISABLED"
+    
     CONST_MAINTENANCE_MODE_ENABLED_INHERITED = "ENABLED_INHERITED"
     
     CONST_ENCRYPTION_ENABLED = "ENABLED"
@@ -238,15 +278,21 @@ class NUDomain(NURESTObject):
         
         self._pat_enabled = None
         self._ecmp_count = None
+        self._bgp_enabled = None
         self._dhcp_behavior = None
         self._dhcp_server_address = None
+        self._fip_underlay = None
+        self._dpi = None
         self._label_id = None
         self._back_haul_route_distinguisher = None
         self._back_haul_route_target = None
+        self._back_haul_subnet_ip_address = None
+        self._back_haul_subnet_mask = None
         self._back_haul_vnid = None
         self._maintenance_mode = None
         self._name = None
         self._last_updated_by = None
+        self._advertise_criteria = None
         self._leaking_enabled = None
         self._secondary_dhcp_server_address = None
         self._template_id = None
@@ -259,12 +305,17 @@ class NUDomain(NURESTObject):
         self._encryption = None
         self._underlay_enabled = None
         self._entity_scope = None
+        self._local_as = None
         self._policy_change_status = None
+        self._domain_id = None
+        self._domain_vlanid = None
         self._route_distinguisher = None
         self._route_target = None
         self._uplink_preference = None
-        self._application_deployment_policy = None
+        self._associated_bgp_profile_id = None
         self._associated_multicast_channel_map_id = None
+        self._associated_pat_mapper_id = None
+        self._associated_shared_pat_mapper_id = None
         self._stretched = None
         self._multicast = None
         self._tunnel_type = None
@@ -274,15 +325,21 @@ class NUDomain(NURESTObject):
         
         self.expose_attribute(local_name="pat_enabled", remote_name="PATEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="ecmp_count", remote_name="ECMPCount", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="dhcp_behavior", remote_name="DHCPBehavior", attribute_type=str, is_required=False, is_unique=False, choices=[u'CONSUME', u'FLOOD', u'RELAY'])
+        self.expose_attribute(local_name="bgp_enabled", remote_name="BGPEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="dhcp_behavior", remote_name="DHCPBehavior", attribute_type=str, is_required=False, is_unique=False, choices=[u'CONSUME', u'FLOOD', u'OVERLAY_RELAY', u'UNDERLAY_RELAY'])
         self.expose_attribute(local_name="dhcp_server_address", remote_name="DHCPServerAddress", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="fip_underlay", remote_name="FIPUnderlay", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="dpi", remote_name="DPI", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="label_id", remote_name="labelID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="back_haul_route_distinguisher", remote_name="backHaulRouteDistinguisher", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="back_haul_route_target", remote_name="backHaulRouteTarget", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="back_haul_subnet_ip_address", remote_name="backHaulSubnetIPAddress", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="back_haul_subnet_mask", remote_name="backHaulSubnetMask", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="back_haul_vnid", remote_name="backHaulVNID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="maintenance_mode", remote_name="maintenanceMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'ENABLED_INHERITED'])
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="advertise_criteria", remote_name="advertiseCriteria", attribute_type=str, is_required=False, is_unique=False, choices=[u'HUB_ROUTES'])
         self.expose_attribute(local_name="leaking_enabled", remote_name="leakingEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="secondary_dhcp_server_address", remote_name="secondaryDHCPServerAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="template_id", remote_name="templateID", attribute_type=str, is_required=True, is_unique=False)
@@ -295,12 +352,17 @@ class NUDomain(NURESTObject):
         self.expose_attribute(local_name="encryption", remote_name="encryption", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="underlay_enabled", remote_name="underlayEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="local_as", remote_name="localAS", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="policy_change_status", remote_name="policyChangeStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'APPLIED', u'DISCARDED', u'STARTED'])
+        self.expose_attribute(local_name="domain_id", remote_name="domainID", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="domain_vlanid", remote_name="domainVLANID", attribute_type=int, is_required=False, is_unique=True)
         self.expose_attribute(local_name="route_distinguisher", remote_name="routeDistinguisher", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="route_target", remote_name="routeTarget", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="uplink_preference", remote_name="uplinkPreference", attribute_type=str, is_required=False, is_unique=False, choices=[u'PRIMARY', u'PRIMARY_SECONDARY', u'SECONDARY', u'SECONDARY_PRIMARY', u'SYMMETRIC'])
-        self.expose_attribute(local_name="application_deployment_policy", remote_name="applicationDeploymentPolicy", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'ZONE'])
+        self.expose_attribute(local_name="associated_bgp_profile_id", remote_name="associatedBGPProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_multicast_channel_map_id", remote_name="associatedMulticastChannelMapID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_pat_mapper_id", remote_name="associatedPATMapperID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_shared_pat_mapper_id", remote_name="associatedSharedPATMapperID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stretched", remote_name="stretched", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="tunnel_type", remote_name="tunnelType", attribute_type=str, is_required=False, is_unique=False, choices=[u'DC_DEFAULT', u'GRE', u'VXLAN'])
@@ -324,15 +386,36 @@ class NUDomain(NURESTObject):
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.network_performance_bindings = NUNetworkPerformanceBindingsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.pg_expressions = NUPGExpressionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.egress_acl_entry_templates = NUEgressACLEntryTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.egress_acl_templates = NUEgressACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.egress_adv_fwd_templates = NUEgressAdvFwdTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.domain_fip_acl_templates = NUDomainFIPAclTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.floating_ipacl_templates = NUFloatingIPACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.dhcp_options = NUDHCPOptionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.links = NULinksFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.firewall_acls = NUFirewallAclsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.floating_ips = NUFloatingIpsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -345,6 +428,9 @@ class NUDomain(NURESTObject):
         self.vm_interfaces = NUVMInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.vnf_domain_mappings = NUVNFDomainMappingsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.ingress_acl_entry_templates = NUIngressACLEntryTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -372,12 +458,24 @@ class NUDomain(NURESTObject):
         self.zones = NUZonesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.containers = NUContainersFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.container_interfaces = NUContainerInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.qoss = NUQOSsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.host_interfaces = NUHostInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.routing_policies = NURoutingPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.spat_sources_pools = NUSPATSourcesPoolsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.uplink_rds = NUUplinkRDsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -387,6 +485,9 @@ class NUDomain(NURESTObject):
         self.vports = NUVPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.applicationperformancemanagementbindings = NUApplicationperformancemanagementbindingsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.bridge_interfaces = NUBridgeInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -407,9 +508,6 @@ class NUDomain(NURESTObject):
         
         self.event_logs = NUEventLogsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
-        
-        self.external_app_services = NUExternalAppServicesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
 
         self._compute_args(**kwargs)
 
@@ -469,12 +567,39 @@ class NUDomain(NURESTObject):
         self._ecmp_count = value
 
     
+    @property
+    def bgp_enabled(self):
+        """ Get bgp_enabled value.
+
+            Notes:
+                Read only flag to display if BGP is enabled for this domain
+
+                
+                This attribute is named `BGPEnabled` in VSD API.
+                
+        """
+        return self._bgp_enabled
+
+    @bgp_enabled.setter
+    def bgp_enabled(self, value):
+        """ Set bgp_enabled value.
+
+            Notes:
+                Read only flag to display if BGP is enabled for this domain
+
+                
+                This attribute is named `BGPEnabled` in VSD API.
+                
+        """
+        self._bgp_enabled = value
+
+    
     @property
     def dhcp_behavior(self):
         """ Get dhcp_behavior value.
 
             Notes:
-                DHCPBehaviorType is an enum that indicates DHCP Behavior of VRS having VM's under this domain. Possible values are FLOOD, CONSUME ,RELAY Possible values are CONSUME, FLOOD, RELAY, .
+                DHCPBehaviorType is an enum that indicates DHCP Behavior of VRS having VM's under this domain. Possible values are FLOOD, CONSUME, OVERLAY_RELAY, UNDERLAY_RELAY.
 
                 
                 This attribute is named `DHCPBehavior` in VSD API.
@@ -487,7 +612,7 @@ class NUDomain(NURESTObject):
         """ Set dhcp_behavior value.
 
             Notes:
-                DHCPBehaviorType is an enum that indicates DHCP Behavior of VRS having VM's under this domain. Possible values are FLOOD, CONSUME ,RELAY Possible values are CONSUME, FLOOD, RELAY, .
+                DHCPBehaviorType is an enum that indicates DHCP Behavior of VRS having VM's under this domain. Possible values are FLOOD, CONSUME, OVERLAY_RELAY, UNDERLAY_RELAY.
 
                 
                 This attribute is named `DHCPBehavior` in VSD API.
@@ -523,6 +648,60 @@ class NUDomain(NURESTObject):
         self._dhcp_server_address = value
 
     
+    @property
+    def fip_underlay(self):
+        """ Get fip_underlay value.
+
+            Notes:
+                Boolean flag to indicate whether this is a Floating IP to underlay domain or not
+
+                
+                This attribute is named `FIPUnderlay` in VSD API.
+                
+        """
+        return self._fip_underlay
+
+    @fip_underlay.setter
+    def fip_underlay(self, value):
+        """ Set fip_underlay value.
+
+            Notes:
+                Boolean flag to indicate whether this is a Floating IP to underlay domain or not
+
+                
+                This attribute is named `FIPUnderlay` in VSD API.
+                
+        """
+        self._fip_underlay = value
+
+    
+    @property
+    def dpi(self):
+        """ Get dpi value.
+
+            Notes:
+                determines whether or not Deep packet inspection is enabled
+
+                
+                This attribute is named `DPI` in VSD API.
+                
+        """
+        return self._dpi
+
+    @dpi.setter
+    def dpi(self, value):
+        """ Set dpi value.
+
+            Notes:
+                determines whether or not Deep packet inspection is enabled
+
+                
+                This attribute is named `DPI` in VSD API.
+                
+        """
+        self._dpi = value
+
+    
     @property
     def label_id(self):
         """ Get label_id value.
@@ -604,6 +783,60 @@ class NUDomain(NURESTObject):
         self._back_haul_route_target = value
 
     
+    @property
+    def back_haul_subnet_ip_address(self):
+        """ Get back_haul_subnet_ip_address value.
+
+            Notes:
+                IP Address of the backhaul subnet 
+
+                
+                This attribute is named `backHaulSubnetIPAddress` in VSD API.
+                
+        """
+        return self._back_haul_subnet_ip_address
+
+    @back_haul_subnet_ip_address.setter
+    def back_haul_subnet_ip_address(self, value):
+        """ Set back_haul_subnet_ip_address value.
+
+            Notes:
+                IP Address of the backhaul subnet 
+
+                
+                This attribute is named `backHaulSubnetIPAddress` in VSD API.
+                
+        """
+        self._back_haul_subnet_ip_address = value
+
+    
+    @property
+    def back_haul_subnet_mask(self):
+        """ Get back_haul_subnet_mask value.
+
+            Notes:
+                Network mask of the backhaul subnet
+
+                
+                This attribute is named `backHaulSubnetMask` in VSD API.
+                
+        """
+        return self._back_haul_subnet_mask
+
+    @back_haul_subnet_mask.setter
+    def back_haul_subnet_mask(self, value):
+        """ Set back_haul_subnet_mask value.
+
+            Notes:
+                Network mask of the backhaul subnet
+
+                
+                This attribute is named `backHaulSubnetMask` in VSD API.
+                
+        """
+        self._back_haul_subnet_mask = value
+
+    
     @property
     def back_haul_vnid(self):
         """ Get back_haul_vnid value.
@@ -708,6 +941,33 @@ class NUDomain(NURESTObject):
         self._last_updated_by = value
 
     
+    @property
+    def advertise_criteria(self):
+        """ Get advertise_criteria value.
+
+            Notes:
+                Set this attribute to allow the spoke domain routes to be leaked into the hub domain.
+
+                
+                This attribute is named `advertiseCriteria` in VSD API.
+                
+        """
+        return self._advertise_criteria
+
+    @advertise_criteria.setter
+    def advertise_criteria(self, value):
+        """ Set advertise_criteria value.
+
+            Notes:
+                Set this attribute to allow the spoke domain routes to be leaked into the hub domain.
+
+                
+                This attribute is named `advertiseCriteria` in VSD API.
+                
+        """
+        self._advertise_criteria = value
+
+    
     @property
     def leaking_enabled(self):
         """ Get leaking_enabled value.
@@ -1024,6 +1284,33 @@ class NUDomain(NURESTObject):
         self._entity_scope = value
 
     
+    @property
+    def local_as(self):
+        """ Get local_as value.
+
+            Notes:
+                Local autonomous system for the domain
+
+                
+                This attribute is named `localAS` in VSD API.
+                
+        """
+        return self._local_as
+
+    @local_as.setter
+    def local_as(self, value):
+        """ Set local_as value.
+
+            Notes:
+                Local autonomous system for the domain
+
+                
+                This attribute is named `localAS` in VSD API.
+                
+        """
+        self._local_as = value
+
+    
     @property
     def policy_change_status(self):
         """ Get policy_change_status value.
@@ -1051,6 +1338,60 @@ class NUDomain(NURESTObject):
         self._policy_change_status = value
 
     
+    @property
+    def domain_id(self):
+        """ Get domain_id value.
+
+            Notes:
+                A unique 20-bitID editable however could be auto-generated by VSD.
+
+                
+                This attribute is named `domainID` in VSD API.
+                
+        """
+        return self._domain_id
+
+    @domain_id.setter
+    def domain_id(self, value):
+        """ Set domain_id value.
+
+            Notes:
+                A unique 20-bitID editable however could be auto-generated by VSD.
+
+                
+                This attribute is named `domainID` in VSD API.
+                
+        """
+        self._domain_id = value
+
+    
+    @property
+    def domain_vlanid(self):
+        """ Get domain_vlanid value.
+
+            Notes:
+                None
+
+                
+                This attribute is named `domainVLANID` in VSD API.
+                
+        """
+        return self._domain_vlanid
+
+    @domain_vlanid.setter
+    def domain_vlanid(self, value):
+        """ Set domain_vlanid value.
+
+            Notes:
+                None
+
+                
+                This attribute is named `domainVLANID` in VSD API.
+                
+        """
+        self._domain_vlanid = value
+
+    
     @property
     def route_distinguisher(self):
         """ Get route_distinguisher value.
@@ -1133,30 +1474,30 @@ class NUDomain(NURESTObject):
 
     
     @property
-    def application_deployment_policy(self):
-        """ Get application_deployment_policy value.
+    def associated_bgp_profile_id(self):
+        """ Get associated_bgp_profile_id value.
 
             Notes:
-                Application deployment policy.
+                None
 
                 
-                This attribute is named `applicationDeploymentPolicy` in VSD API.
+                This attribute is named `associatedBGPProfileID` in VSD API.
                 
         """
-        return self._application_deployment_policy
+        return self._associated_bgp_profile_id
 
-    @application_deployment_policy.setter
-    def application_deployment_policy(self, value):
-        """ Set application_deployment_policy value.
+    @associated_bgp_profile_id.setter
+    def associated_bgp_profile_id(self, value):
+        """ Set associated_bgp_profile_id value.
 
             Notes:
-                Application deployment policy.
+                None
 
                 
-                This attribute is named `applicationDeploymentPolicy` in VSD API.
+                This attribute is named `associatedBGPProfileID` in VSD API.
                 
         """
-        self._application_deployment_policy = value
+        self._associated_bgp_profile_id = value
 
     
     @property
@@ -1186,6 +1527,60 @@ class NUDomain(NURESTObject):
         self._associated_multicast_channel_map_id = value
 
     
+    @property
+    def associated_pat_mapper_id(self):
+        """ Get associated_pat_mapper_id value.
+
+            Notes:
+                The ID of the PatMapper entity to which this l3-domain is associated to.
+
+                
+                This attribute is named `associatedPATMapperID` in VSD API.
+                
+        """
+        return self._associated_pat_mapper_id
+
+    @associated_pat_mapper_id.setter
+    def associated_pat_mapper_id(self, value):
+        """ Set associated_pat_mapper_id value.
+
+            Notes:
+                The ID of the PatMapper entity to which this l3-domain is associated to.
+
+                
+                This attribute is named `associatedPATMapperID` in VSD API.
+                
+        """
+        self._associated_pat_mapper_id = value
+
+    
+    @property
+    def associated_shared_pat_mapper_id(self):
+        """ Get associated_shared_pat_mapper_id value.
+
+            Notes:
+                The ID of the PatMapper entity to which this SharedNetworkResource is associated to.
+
+                
+                This attribute is named `associatedSharedPATMapperID` in VSD API.
+                
+        """
+        return self._associated_shared_pat_mapper_id
+
+    @associated_shared_pat_mapper_id.setter
+    def associated_shared_pat_mapper_id(self, value):
+        """ Set associated_shared_pat_mapper_id value.
+
+            Notes:
+                The ID of the PatMapper entity to which this SharedNetworkResource is associated to.
+
+                
+                This attribute is named `associatedSharedPATMapperID` in VSD API.
+                
+        """
+        self._associated_shared_pat_mapper_id = value
+
+    
     @property
     def stretched(self):
         """ Get stretched value.
