@@ -42,6 +42,9 @@ from .fetchers import NUGatewaysFetcher
 from .fetchers import NUGatewayTemplatesFetcher
 
 
+from .fetchers import NUPATMappersFetcher
+
+
 from .fetchers import NUPATNATPoolsFetcher
 
 
@@ -60,24 +63,45 @@ from .fetchers import NURedirectionTargetsFetcher
 from .fetchers import NURedundancyGroupsFetcher
 
 
+from .fetchers import NUPerformanceMonitorsFetcher
+
+
 from .fetchers import NUCertificatesFetcher
 
 
 from .fetchers import NUMetadatasFetcher
 
 
-from .fetchers import NUMetadataTagsFetcher
-
-
 from .fetchers import NUNetworkLayoutsFetcher
 
 
+from .fetchers import NUKeyServerMembersFetcher
+
+
+from .fetchers import NUZFBAutoAssignmentsFetcher
+
+
+from .fetchers import NUZFBRequestsFetcher
+
+
+from .fetchers import NUBGPNeighborsFetcher
+
+
+from .fetchers import NUBGPProfilesFetcher
+
+
 from .fetchers import NUEgressACLEntryTemplatesFetcher
 
 
 from .fetchers import NUEgressACLTemplatesFetcher
 
 
+from .fetchers import NUDomainFIPAclTemplatesFetcher
+
+
+from .fetchers import NUFloatingIPACLTemplatesFetcher
+
+
 from .fetchers import NUEgressQOSPoliciesFetcher
 
 
@@ -87,6 +111,9 @@ from .fetchers import NUSharedNetworkResourcesFetcher
 from .fetchers import NULicensesFetcher
 
 
+from .fetchers import NULicenseStatusFetcher
+
+
 from .fetchers import NUMirrorDestinationsFetcher
 
 
@@ -108,12 +135,21 @@ from .fetchers import NUVMInterfacesFetcher
 from .fetchers import NUCloudMgmtSystemsFetcher
 
 
+from .fetchers import NUUnderlaysFetcher
+
+
+from .fetchers import NUVNFCatalogsFetcher
+
+
+from .fetchers import NUVNFMetadatasFetcher
+
+
+from .fetchers import NUInfrastructureAccessProfilesFetcher
+
+
 from .fetchers import NUInfrastructureGatewayProfilesFetcher
 
 
-from .fetchers import NUInfrastructurePortProfilesFetcher
-
-
 from .fetchers import NUInfrastructureVscProfilesFetcher
 
 
@@ -126,6 +162,9 @@ from .fetchers import NUIngressACLTemplatesFetcher
 from .fetchers import NUIngressAdvFwdEntryTemplatesFetcher
 
 
+from .fetchers import NUIngressQOSPoliciesFetcher
+
+
 from .fetchers import NUEnterprisesFetcher
 
 
@@ -144,18 +183,30 @@ from .fetchers import NUDomainsFetcher
 from .fetchers import NUZonesFetcher
 
 
+from .fetchers import NUContainersFetcher
+
+
+from .fetchers import NUContainerInterfacesFetcher
+
+
+from .fetchers import NUCOSRemarkingPolicyTablesFetcher
+
+
 from .fetchers import NUHostInterfacesFetcher
 
 
+from .fetchers import NURoutingPoliciesFetcher
+
+
 from .fetchers import NUUplinkRDsFetcher
 
 
-from .fetchers import NUApplicationServicesFetcher
-
-
 from .fetchers import NUVCenterVRSConfigsFetcher
 
 
+from .fetchers import NUDSCPRemarkingPolicyTablesFetcher
+
+
 from .fetchers import NUUsersFetcher
 
 
@@ -165,15 +216,18 @@ from .fetchers import NUNSGatewaysFetcher
 from .fetchers import NUNSGatewayTemplatesFetcher
 
 
+from .fetchers import NUNSGGroupsFetcher
+
+
 from .fetchers import NUNSRedundantGatewayGroupsFetcher
 
 
+from .fetchers import NUNSGUpgradeProfilesFetcher
+
+
 from .fetchers import NUVSPsFetcher
 
 
-from .fetchers import NUNSPortStaticConfigurationsFetcher
-
-
 from .fetchers import NUStaticRoutesFetcher
 
 
@@ -183,18 +237,15 @@ from .fetchers import NUStatsCollectorInfosFetcher
 from .fetchers import NUSubnetsFetcher
 
 
+from .fetchers import NUDUCGroupsFetcher
+
+
 from .fetchers import NUMultiCastChannelMapsFetcher
 
 
 from .fetchers import NUAutoDiscoveredGatewaysFetcher
 
 
-from .fetchers import NUExternalAppServicesFetcher
-
-
-from .fetchers import NUExternalServicesFetcher
-
-
 from .fetchers import NUSystemConfigsFetcher
 
 from bambou import NURESTRootObject
@@ -242,11 +293,16 @@ class NUMe(NURESTRootObject):
 
         # Read/Write Attributes
         
+        self._aar_flow_stats_interval = None
+        self._aar_probe_stats_interval = None
+        self._vss_stats_interval = None
         self._password = None
         self._last_name = None
         self._last_updated_by = None
         self._first_name = None
         self._disabled = None
+        self._elastic_search_address = None
+        self._flow_collection_enabled = None
         self._email = None
         self._enterprise_id = None
         self._enterprise_name = None
@@ -254,15 +310,21 @@ class NUMe(NURESTRootObject):
         self._mobile_number = None
         self._role = None
         self._user_name = None
+        self._statistics_enabled = None
         self._avatar_data = None
         self._avatar_type = None
         self._external_id = None
         
+        self.expose_attribute(local_name="aar_flow_stats_interval", remote_name="AARFlowStatsInterval", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="aar_probe_stats_interval", remote_name="AARProbeStatsInterval", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="vss_stats_interval", remote_name="VSSStatsInterval", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="password", remote_name="password", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_name", remote_name="lastName", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="first_name", remote_name="firstName", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="disabled", remote_name="disabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="elastic_search_address", remote_name="elasticSearchAddress", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="flow_collection_enabled", remote_name="flowCollectionEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="email", remote_name="email", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="enterprise_id", remote_name="enterpriseID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="enterprise_name", remote_name="enterpriseName", attribute_type=str, is_required=False, is_unique=False)
@@ -270,6 +332,7 @@ class NUMe(NURESTRootObject):
         self.expose_attribute(local_name="mobile_number", remote_name="mobileNumber", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="role", remote_name="role", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="user_name", remote_name="userName", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="statistics_enabled", remote_name="statisticsEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="avatar_data", remote_name="avatarData", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="avatar_type", remote_name="avatarType", attribute_type=str, is_required=False, is_unique=False, choices=[u'BASE64', u'COMPUTEDURL', u'URL'])
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
@@ -293,6 +356,9 @@ class NUMe(NURESTRootObject):
         self.gateway_templates = NUGatewayTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.pat_mappers = NUPATMappersFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.patnat_pools = NUPATNATPoolsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -311,24 +377,45 @@ class NUMe(NURESTRootObject):
         self.redundancy_groups = NURedundancyGroupsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.performance_monitors = NUPerformanceMonitorsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.certificates = NUCertificatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.metadata_tags = NUMetadataTagsFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.network_layouts = NUNetworkLayoutsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.key_server_members = NUKeyServerMembersFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.zfb_auto_assignments = NUZFBAutoAssignmentsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.zfb_requests = NUZFBRequestsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.bgp_neighbors = NUBGPNeighborsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.bgp_profiles = NUBGPProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.egress_acl_entry_templates = NUEgressACLEntryTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
         self.egress_acl_templates = NUEgressACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.domain_fip_acl_templates = NUDomainFIPAclTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.floating_ipacl_templates = NUFloatingIPACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.egress_qos_policies = NUEgressQOSPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -338,6 +425,9 @@ class NUMe(NURESTRootObject):
         self.licenses = NULicensesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.license_status = NULicenseStatusFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.mirror_destinations = NUMirrorDestinationsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -359,12 +449,21 @@ class NUMe(NURESTRootObject):
         self.cloud_mgmt_systems = NUCloudMgmtSystemsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.underlays = NUUnderlaysFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.vnf_catalogs = NUVNFCatalogsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.vnf_metadatas = NUVNFMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.infrastructure_access_profiles = NUInfrastructureAccessProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.infrastructure_gateway_profiles = NUInfrastructureGatewayProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.infrastructure_port_profiles = NUInfrastructurePortProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.infrastructure_vsc_profiles = NUInfrastructureVscProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -377,6 +476,9 @@ class NUMe(NURESTRootObject):
         self.ingress_adv_fwd_entry_templates = NUIngressAdvFwdEntryTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.ingress_qos_policies = NUIngressQOSPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.enterprises = NUEnterprisesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -395,18 +497,30 @@ class NUMe(NURESTRootObject):
         self.zones = NUZonesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.containers = NUContainersFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.container_interfaces = NUContainerInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
+        self.cos_remarking_policy_tables = NUCOSRemarkingPolicyTablesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.host_interfaces = NUHostInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.routing_policies = NURoutingPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.uplink_rds = NUUplinkRDsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.application_services = NUApplicationServicesFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.vcenter_vrs_configs = NUVCenterVRSConfigsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.dscp_remarking_policy_tables = NUDSCPRemarkingPolicyTablesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.users = NUUsersFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -416,15 +530,18 @@ class NUMe(NURESTRootObject):
         self.ns_gateway_templates = NUNSGatewayTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.nsg_groups = NUNSGGroupsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.ns_redundant_gateway_groups = NUNSRedundantGatewayGroupsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.nsg_upgrade_profiles = NUNSGUpgradeProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.vsps = NUVSPsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.ns_port_static_configurations = NUNSPortStaticConfigurationsFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.static_routes = NUStaticRoutesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -434,18 +551,15 @@ class NUMe(NURESTRootObject):
         self.subnets = NUSubnetsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.duc_groups = NUDUCGroupsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.multi_cast_channel_maps = NUMultiCastChannelMapsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
         self.auto_discovered_gateways = NUAutoDiscoveredGatewaysFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.external_app_services = NUExternalAppServicesFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
-        self.external_services = NUExternalServicesFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.system_configs = NUSystemConfigsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
 
@@ -453,6 +567,87 @@ class NUMe(NURESTRootObject):
 
     # Properties
     
+    @property
+    def aar_flow_stats_interval(self):
+        """ Get aar_flow_stats_interval value.
+
+            Notes:
+                AAR flow stats frequency
+
+                
+                This attribute is named `AARFlowStatsInterval` in VSD API.
+                
+        """
+        return self._aar_flow_stats_interval
+
+    @aar_flow_stats_interval.setter
+    def aar_flow_stats_interval(self, value):
+        """ Set aar_flow_stats_interval value.
+
+            Notes:
+                AAR flow stats frequency
+
+                
+                This attribute is named `AARFlowStatsInterval` in VSD API.
+                
+        """
+        self._aar_flow_stats_interval = value
+
+    
+    @property
+    def aar_probe_stats_interval(self):
+        """ Get aar_probe_stats_interval value.
+
+            Notes:
+                AAR Probe stats frequency
+
+                
+                This attribute is named `AARProbeStatsInterval` in VSD API.
+                
+        """
+        return self._aar_probe_stats_interval
+
+    @aar_probe_stats_interval.setter
+    def aar_probe_stats_interval(self, value):
+        """ Set aar_probe_stats_interval value.
+
+            Notes:
+                AAR Probe stats frequency
+
+                
+                This attribute is named `AARProbeStatsInterval` in VSD API.
+                
+        """
+        self._aar_probe_stats_interval = value
+
+    
+    @property
+    def vss_stats_interval(self):
+        """ Get vss_stats_interval value.
+
+            Notes:
+                VSS flow stats frequency
+
+                
+                This attribute is named `VSSStatsInterval` in VSD API.
+                
+        """
+        return self._vss_stats_interval
+
+    @vss_stats_interval.setter
+    def vss_stats_interval(self, value):
+        """ Set vss_stats_interval value.
+
+            Notes:
+                VSS flow stats frequency
+
+                
+                This attribute is named `VSSStatsInterval` in VSD API.
+                
+        """
+        self._vss_stats_interval = value
+
+    
     @property
     def password(self):
         """ Get password value.
@@ -580,6 +775,60 @@ class NUMe(NURESTRootObject):
         self._disabled = value
 
     
+    @property
+    def elastic_search_address(self):
+        """ Get elastic_search_address value.
+
+            Notes:
+                elastic search address
+
+                
+                This attribute is named `elasticSearchAddress` in VSD API.
+                
+        """
+        return self._elastic_search_address
+
+    @elastic_search_address.setter
+    def elastic_search_address(self, value):
+        """ Set elastic_search_address value.
+
+            Notes:
+                elastic search address
+
+                
+                This attribute is named `elasticSearchAddress` in VSD API.
+                
+        """
+        self._elastic_search_address = value
+
+    
+    @property
+    def flow_collection_enabled(self):
+        """ Get flow_collection_enabled value.
+
+            Notes:
+                Enables flow statistics collection. It is needed for the VSS feature, and requires a valid VSS license. This option requires "statisticsEnabled".
+
+                
+                This attribute is named `flowCollectionEnabled` in VSD API.
+                
+        """
+        return self._flow_collection_enabled
+
+    @flow_collection_enabled.setter
+    def flow_collection_enabled(self, value):
+        """ Set flow_collection_enabled value.
+
+            Notes:
+                Enables flow statistics collection. It is needed for the VSS feature, and requires a valid VSS license. This option requires "statisticsEnabled".
+
+                
+                This attribute is named `flowCollectionEnabled` in VSD API.
+                
+        """
+        self._flow_collection_enabled = value
+
+    
     @property
     def email(self):
         """ Get email value.
@@ -761,6 +1010,33 @@ class NUMe(NURESTRootObject):
         self._user_name = value
 
     
+    @property
+    def statistics_enabled(self):
+        """ Get statistics_enabled value.
+
+            Notes:
+                This flag is used to indicate if statistics is enabled in the system. CSProot is expected to activate this through the enable statistics script.
+
+                
+                This attribute is named `statisticsEnabled` in VSD API.
+                
+        """
+        return self._statistics_enabled
+
+    @statistics_enabled.setter
+    def statistics_enabled(self, value):
+        """ Set statistics_enabled value.
+
+            Notes:
+                This flag is used to indicate if statistics is enabled in the system. CSProot is expected to activate this through the enable statistics script.
+
+                
+                This attribute is named `statisticsEnabled` in VSD API.
+                
+        """
+        self._statistics_enabled = value
+
+    
     @property
     def avatar_data(self):
         """ Get avatar_data value.
