@@ -30,6 +30,9 @@
 from .fetchers import NUNATMapEntriesFetcher
 
 
+from .fetchers import NUAddressMapsFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -38,6 +41,15 @@ from .fetchers import NUGlobalMetadatasFetcher
 
 from .fetchers import NUEnterprisePermissionsFetcher
 
+
+from .fetchers import NUStatisticsFetcher
+
+
+from .fetchers import NUStatisticsPoliciesFetcher
+
+
+from .fetchers import NUBulkStatisticsFetcher
+
 from bambou import NURESTObject
 
 
@@ -66,14 +78,14 @@ class NUPATNATPool(NURESTObject):
     
     CONST_PERMITTED_ACTION_EXTEND = "EXTEND"
     
+    CONST_ASSOCIATED_GATEWAY_TYPE_IKE_GATEWAY = "IKE_GATEWAY"
+    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
     CONST_PERMITTED_ACTION_INSTANTIATE = "INSTANTIATE"
     
     CONST_ASSOCIATED_GATEWAY_TYPE_NSGATEWAY = "NSGATEWAY"
     
-    CONST_ASSOCIATED_GATEWAY_TYPE_IKEV2_GATEWAY = "IKEV2_GATEWAY"
-    
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
     CONST_ASSOCIATED_GATEWAY_TYPE_AUTO_DISC_GATEWAY = "AUTO_DISC_GATEWAY"
@@ -103,21 +115,35 @@ class NUPATNATPool(NURESTObject):
         self._default_patip = None
         self._permitted_action = None
         self._description = None
+        self._end_address_range = None
+        self._end_source_address = None
         self._entity_scope = None
         self._associated_gateway_id = None
         self._associated_gateway_type = None
+        self._associated_subnet_id = None
+        self._associated_vlan_id = None
+        self._start_address_range = None
+        self._start_source_address = None
         self._external_id = None
+        self._dynamic_source_enabled = None
         
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="address_range", remote_name="addressRange", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="address_range", remote_name="addressRange", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="default_patip", remote_name="defaultPATIP", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="end_address_range", remote_name="endAddressRange", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="end_source_address", remote_name="endSourceAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="associated_gateway_id", remote_name="associatedGatewayId", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="associated_gateway_type", remote_name="associatedGatewayType", attribute_type=str, is_required=False, is_unique=False, choices=[u'AUTO_DISC_GATEWAY', u'GATEWAY', u'IKEV2_GATEWAY', u'NSGATEWAY'])
+        self.expose_attribute(local_name="associated_gateway_type", remote_name="associatedGatewayType", attribute_type=str, is_required=False, is_unique=False, choices=[u'AUTO_DISC_GATEWAY', u'GATEWAY', u'IKE_GATEWAY', u'NSGATEWAY'])
+        self.expose_attribute(local_name="associated_subnet_id", remote_name="associatedSubnetId", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_vlan_id", remote_name="associatedVlanId", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="start_address_range", remote_name="startAddressRange", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="start_source_address", remote_name="startSourceAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
+        self.expose_attribute(local_name="dynamic_source_enabled", remote_name="dynamicSourceEnabled", attribute_type=bool, is_required=False, is_unique=False)
         
 
         # Fetchers
@@ -126,6 +152,9 @@ class NUPATNATPool(NURESTObject):
         self.nat_map_entries = NUNATMapEntriesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.address_maps = NUAddressMapsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -134,6 +163,15 @@ class NUPATNATPool(NURESTObject):
         
         self.enterprise_permissions = NUEnterprisePermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
+        
+        self.statistics = NUStatisticsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.statistics_policies = NUStatisticsPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.bulk_statistics = NUBulkStatisticsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
 
         self._compute_args(**kwargs)
 
@@ -194,7 +232,7 @@ class NUPATNATPool(NURESTObject):
         """ Get address_range value.
 
             Notes:
-                Pool of IP Address that is available for use ex : 130.12.0.0/16
+                Default PAT IP Address, must belong to the pool above
 
                 
                 This attribute is named `addressRange` in VSD API.
@@ -207,7 +245,7 @@ class NUPATNATPool(NURESTObject):
         """ Set address_range value.
 
             Notes:
-                Pool of IP Address that is available for use ex : 130.12.0.0/16
+                Default PAT IP Address, must belong to the pool above
 
                 
                 This attribute is named `addressRange` in VSD API.
@@ -293,6 +331,60 @@ class NUPATNATPool(NURESTObject):
         self._description = value
 
     
+    @property
+    def end_address_range(self):
+        """ Get end_address_range value.
+
+            Notes:
+                Ending IP Address for the pool of available addresses for use
+
+                
+                This attribute is named `endAddressRange` in VSD API.
+                
+        """
+        return self._end_address_range
+
+    @end_address_range.setter
+    def end_address_range(self, value):
+        """ Set end_address_range value.
+
+            Notes:
+                Ending IP Address for the pool of available addresses for use
+
+                
+                This attribute is named `endAddressRange` in VSD API.
+                
+        """
+        self._end_address_range = value
+
+    
+    @property
+    def end_source_address(self):
+        """ Get end_source_address value.
+
+            Notes:
+                Ending Source IP Address for the pool. (Dynamic Source NAT)
+
+                
+                This attribute is named `endSourceAddress` in VSD API.
+                
+        """
+        return self._end_source_address
+
+    @end_source_address.setter
+    def end_source_address(self, value):
+        """ Set end_source_address value.
+
+            Notes:
+                Ending Source IP Address for the pool. (Dynamic Source NAT)
+
+                
+                This attribute is named `endSourceAddress` in VSD API.
+                
+        """
+        self._end_source_address = value
+
+    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
@@ -325,7 +417,7 @@ class NUPATNATPool(NURESTObject):
         """ Get associated_gateway_id value.
 
             Notes:
-                Default PAT IP Address, must belong to the pool above
+                UUID of the NSG instance this Pool is assocated with. This attribute may be auto-populated when the pool is assigned to a Network VLAN instance.
 
                 
                 This attribute is named `associatedGatewayId` in VSD API.
@@ -338,7 +430,7 @@ class NUPATNATPool(NURESTObject):
         """ Set associated_gateway_id value.
 
             Notes:
-                Default PAT IP Address, must belong to the pool above
+                UUID of the NSG instance this Pool is assocated with. This attribute may be auto-populated when the pool is assigned to a Network VLAN instance.
 
                 
                 This attribute is named `associatedGatewayId` in VSD API.
@@ -352,7 +444,7 @@ class NUPATNATPool(NURESTObject):
         """ Get associated_gateway_type value.
 
             Notes:
-                
+                None
 
                 
                 This attribute is named `associatedGatewayType` in VSD API.
@@ -365,7 +457,7 @@ class NUPATNATPool(NURESTObject):
         """ Set associated_gateway_type value.
 
             Notes:
-                
+                None
 
                 
                 This attribute is named `associatedGatewayType` in VSD API.
@@ -374,6 +466,114 @@ class NUPATNATPool(NURESTObject):
         self._associated_gateway_type = value
 
     
+    @property
+    def associated_subnet_id(self):
+        """ Get associated_subnet_id value.
+
+            Notes:
+                ID of the Subnet for which the information will be used to populate Source Address Range (Dynamic Source NAT).
+
+                
+                This attribute is named `associatedSubnetId` in VSD API.
+                
+        """
+        return self._associated_subnet_id
+
+    @associated_subnet_id.setter
+    def associated_subnet_id(self, value):
+        """ Set associated_subnet_id value.
+
+            Notes:
+                ID of the Subnet for which the information will be used to populate Source Address Range (Dynamic Source NAT).
+
+                
+                This attribute is named `associatedSubnetId` in VSD API.
+                
+        """
+        self._associated_subnet_id = value
+
+    
+    @property
+    def associated_vlan_id(self):
+        """ Get associated_vlan_id value.
+
+            Notes:
+                ID of the network port VLAN on which the pool is associated.
+
+                
+                This attribute is named `associatedVlanId` in VSD API.
+                
+        """
+        return self._associated_vlan_id
+
+    @associated_vlan_id.setter
+    def associated_vlan_id(self, value):
+        """ Set associated_vlan_id value.
+
+            Notes:
+                ID of the network port VLAN on which the pool is associated.
+
+                
+                This attribute is named `associatedVlanId` in VSD API.
+                
+        """
+        self._associated_vlan_id = value
+
+    
+    @property
+    def start_address_range(self):
+        """ Get start_address_range value.
+
+            Notes:
+                Starting IP Address for the pool of available addresses for use
+
+                
+                This attribute is named `startAddressRange` in VSD API.
+                
+        """
+        return self._start_address_range
+
+    @start_address_range.setter
+    def start_address_range(self, value):
+        """ Set start_address_range value.
+
+            Notes:
+                Starting IP Address for the pool of available addresses for use
+
+                
+                This attribute is named `startAddressRange` in VSD API.
+                
+        """
+        self._start_address_range = value
+
+    
+    @property
+    def start_source_address(self):
+        """ Get start_source_address value.
+
+            Notes:
+                Starting Source IP Address for the pool. (Dynamic Source NAT)
+
+                
+                This attribute is named `startSourceAddress` in VSD API.
+                
+        """
+        return self._start_source_address
+
+    @start_source_address.setter
+    def start_source_address(self, value):
+        """ Set start_source_address value.
+
+            Notes:
+                Starting Source IP Address for the pool. (Dynamic Source NAT)
+
+                
+                This attribute is named `startSourceAddress` in VSD API.
+                
+        """
+        self._start_source_address = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
@@ -401,5 +601,32 @@ class NUPATNATPool(NURESTObject):
         self._external_id = value
 
     
+    @property
+    def dynamic_source_enabled(self):
+        """ Get dynamic_source_enabled value.
+
+            Notes:
+                Set to True if the address translation pool at the address translation pool definition level
+
+                
+                This attribute is named `dynamicSourceEnabled` in VSD API.
+                
+        """
+        return self._dynamic_source_enabled
+
+    @dynamic_source_enabled.setter
+    def dynamic_source_enabled(self, value):
+        """ Set dynamic_source_enabled value.
+
+            Notes:
+                Set to True if the address translation pool at the address translation pool definition level
+
+                
+                This attribute is named `dynamicSourceEnabled` in VSD API.
+                
+        """
+        self._dynamic_source_enabled = value
+
+    
 
     
\ No newline at end of file
