@@ -64,12 +64,12 @@ class NUTCA(NURESTObject):
     
     CONST_METRIC_TCP_FLAG_RST_IN = "TCP_FLAG_RST_IN"
     
-    CONST_METRIC_TCP_FLAG_ACK_OUT = "TCP_FLAG_ACK_OUT"
-    
     CONST_METRIC_EGRESS_PACKET_COUNT = "EGRESS_PACKET_COUNT"
     
     CONST_METRIC_PACKETS_IN_DROPPED = "PACKETS_IN_DROPPED"
     
+    CONST_METRIC_L7_BYTES_OUT = "L7_BYTES_OUT"
+    
     CONST_METRIC_FIP_RATE_LIMIT_DROPPED_BYTES = "FIP_RATE_LIMIT_DROPPED_BYTES"
     
     CONST_METRIC_PACKETS_DROPPED_BY_RATE_LIMIT = "PACKETS_DROPPED_BY_RATE_LIMIT"
@@ -102,6 +102,8 @@ class NUTCA(NURESTObject):
     
     CONST_ACTION_ALERT_POLICYGROUPCHANGE = "ALERT_POLICYGROUPCHANGE"
     
+    CONST_METRIC_PACKETS_IN_ERROR = "PACKETS_IN_ERROR"
+    
     CONST_METRIC_ADDRESS_MAP_EGRESS_PKT_CNT = "ADDRESS_MAP_EGRESS_PKT_CNT"
     
     CONST_METRIC_ADDRESS_MAP_INGRESS_PKT_CNT = "ADDRESS_MAP_INGRESS_PKT_CNT"
@@ -112,7 +114,9 @@ class NUTCA(NURESTObject):
     
     CONST_METRIC_BYTES_OUT = "BYTES_OUT"
     
-    CONST_TYPE_ROLLING_AVERAGE = "ROLLING_AVERAGE"
+    CONST_METRIC_L7_PACKETS_OUT = "L7_PACKETS_OUT"
+    
+    CONST_METRIC_L7_BYTES_IN = "L7_BYTES_IN"
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
@@ -120,6 +124,10 @@ class NUTCA(NURESTObject):
     
     CONST_METRIC_PACKETS_OUT = "PACKETS_OUT"
     
+    CONST_TYPE_ROLLING_AVERAGE = "ROLLING_AVERAGE"
+    
+    CONST_METRIC_CONNECTION_TYPE = "CONNECTION_TYPE"
+    
     CONST_METRIC_FIP_PRE_RATE_LIMIT_PACKETS = "FIP_PRE_RATE_LIMIT_PACKETS"
     
     CONST_ACTION_ALERT = "ALERT"
@@ -128,7 +136,7 @@ class NUTCA(NURESTObject):
     
     CONST_METRIC_TCP_SYN_EVENT_COUNT = "TCP_SYN_EVENT_COUNT"
     
-    CONST_METRIC_PACKETS_IN_ERROR = "PACKETS_IN_ERROR"
+    CONST_METRIC_L7_PACKETS_IN = "L7_PACKETS_IN"
     
     
 
@@ -174,7 +182,7 @@ class NUTCA(NURESTObject):
         self.expose_attribute(local_name="action", remote_name="action", attribute_type=str, is_required=True, is_unique=False, choices=[u'ALERT', u'ALERT_POLICYGROUPCHANGE'])
         self.expose_attribute(local_name="period", remote_name="period", attribute_type=int, is_required=True, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="metric", remote_name="metric", attribute_type=str, is_required=True, is_unique=False, choices=[u'ACL_DENY_EVENT_COUNT', u'ADDRESS_MAP_EGRESS_BYTE_CNT', u'ADDRESS_MAP_EGRESS_PKT_CNT', u'ADDRESS_MAP_INGRESS_BYTE_CNT', u'ADDRESS_MAP_INGRESS_PKT_CNT', u'ANTI_SPOOF_EVENT_COUNT', u'BYTES_IN', u'BYTES_OUT', u'EGRESS_BYTE_COUNT', u'EGRESS_PACKET_COUNT', u'FIP_PRE_RATE_LIMIT_BYTES', u'FIP_PRE_RATE_LIMIT_PACKETS', u'FIP_RATE_LIMIT_DROPPED_BYTES', u'FIP_RATE_LIMIT_DROPPED_PACKETS', u'INGRESS_BYTE_COUNT', u'INGRESS_PACKET_COUNT', u'PACKETS_DROPPED_BY_RATE_LIMIT', u'PACKETS_IN', u'PACKETS_IN_DROPPED', u'PACKETS_IN_ERROR', u'PACKETS_OUT', u'PACKETS_OUT_DROPPED', u'PACKETS_OUT_ERROR', u'TCP_FLAG_ACK_IN', u'TCP_FLAG_ACK_OUT', u'TCP_FLAG_NULL_IN', u'TCP_FLAG_NULL_OUT', u'TCP_FLAG_RST_IN', u'TCP_FLAG_RST_OUT', u'TCP_FLAG_SYN_IN', u'TCP_FLAG_SYN_OUT', u'TCP_SYN_EVENT_COUNT'])
+        self.expose_attribute(local_name="metric", remote_name="metric", attribute_type=str, is_required=True, is_unique=False, choices=[u'ACL_DENY_EVENT_COUNT', u'ADDRESS_MAP_EGRESS_BYTE_CNT', u'ADDRESS_MAP_EGRESS_PKT_CNT', u'ADDRESS_MAP_INGRESS_BYTE_CNT', u'ADDRESS_MAP_INGRESS_PKT_CNT', u'ANTI_SPOOF_EVENT_COUNT', u'BYTES_IN', u'BYTES_OUT', u'CONNECTION_TYPE', u'EGRESS_BYTE_COUNT', u'EGRESS_PACKET_COUNT', u'FIP_PRE_RATE_LIMIT_BYTES', u'FIP_PRE_RATE_LIMIT_PACKETS', u'FIP_RATE_LIMIT_DROPPED_BYTES', u'FIP_RATE_LIMIT_DROPPED_PACKETS', u'INGRESS_BYTE_COUNT', u'INGRESS_PACKET_COUNT', u'L7_BYTES_IN', u'L7_BYTES_OUT', u'L7_PACKETS_IN', u'L7_PACKETS_OUT', u'PACKETS_DROPPED_BY_RATE_LIMIT', u'PACKETS_IN', u'PACKETS_IN_DROPPED', u'PACKETS_IN_ERROR', u'PACKETS_OUT', u'PACKETS_OUT_DROPPED', u'PACKETS_OUT_ERROR', u'TCP_FLAG_ACK_IN', u'TCP_FLAG_NULL_IN', u'TCP_FLAG_NULL_OUT', u'TCP_FLAG_RST_IN', u'TCP_FLAG_RST_OUT', u'TCP_FLAG_SYN_IN', u'TCP_FLAG_SYN_OUT', u'TCP_SYN_EVENT_COUNT'])
         self.expose_attribute(local_name="threshold", remote_name="threshold", attribute_type=int, is_required=True, is_unique=False)
         self.expose_attribute(local_name="throttle_time", remote_name="throttleTime", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="disable", remote_name="disable", attribute_type=bool, is_required=False, is_unique=False)
