@@ -36,8 +36,17 @@ from .fetchers import NUMetadatasFetcher
 from .fetchers import NUGlobalMetadatasFetcher
 
 
+from .fetchers import NUJobsFetcher
+
+
 from .fetchers import NUVRSAddressRangesFetcher
 
+
+from .fetchers import NUVRSRedeploymentpoliciesFetcher
+
+
+from .fetchers import NUAutodiscovereddatacentersFetcher
+
 from bambou import NURESTObject
 
 
@@ -54,10 +63,26 @@ class NUVCenter(NURESTObject):
     
     ## Constants
     
+    CONST_REMOTE_SYSLOG_SERVER_TYPE_NONE = "NONE"
+    
+    CONST_REMOTE_SYSLOG_SERVER_TYPE_UDP = "UDP"
+    
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
+    CONST_DESTINATION_MIRROR_PORT_ENS160 = "ens160"
+    
+    CONST_DESTINATION_MIRROR_PORT_ENS161 = "ens161"
+    
+    CONST_DESTINATION_MIRROR_PORT_NO_MIRROR = "no_mirror"
+    
+    CONST_REMOTE_SYSLOG_SERVER_TYPE_TCP = "TCP"
+    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
+    CONST_DESTINATION_MIRROR_PORT_ENS224 = "ens224"
+    
+    CONST_DESTINATION_MIRROR_PORT_ENS256 = "ens256"
+    
     
 
     def __init__(self, **kwargs):
@@ -77,6 +102,7 @@ class NUVCenter(NURESTObject):
 
         # Read/Write Attributes
         
+        self._vrs_configuration_time_limit = None
         self._v_require_nuage_metadata = None
         self._name = None
         self._password = None
@@ -87,9 +113,14 @@ class NUVCenter(NURESTObject):
         self._data_network_portgroup = None
         self._datapath_sync_timeout = None
         self._secondary_nuage_controller = None
+        self._remote_syslog_server_ip = None
+        self._remote_syslog_server_port = None
+        self._remote_syslog_server_type = None
+        self._generic_split_activation = None
         self._separate_data_network = None
         self._personality = None
         self._description = None
+        self._destination_mirror_port = None
         self._metadata_server_ip = None
         self._metadata_server_listen_port = None
         self._metadata_server_port = None
@@ -105,23 +136,36 @@ class NUVCenter(NURESTObject):
         self._mgmt_gateway = None
         self._mgmt_network_portgroup = None
         self._dhcp_relay_server = None
+        self._mirror_network_portgroup = None
+        self._disable_network_discovery = None
         self._site_id = None
+        self._old_agency_name = None
         self._allow_data_dhcp = None
         self._allow_mgmt_dhcp = None
         self._flow_eviction_threshold = None
         self._vm_network_portgroup = None
         self._entity_scope = None
+        self._connection_status = None
         self._portgroup_metadata = None
         self._host_level_management = None
         self._nova_client_version = None
+        self._nova_identity_url_version = None
         self._nova_metadata_service_auth_url = None
         self._nova_metadata_service_endpoint = None
         self._nova_metadata_service_password = None
         self._nova_metadata_service_tenant = None
         self._nova_metadata_service_username = None
         self._nova_metadata_shared_secret = None
+        self._nova_os_keystone_username = None
+        self._nova_project_domain_name = None
+        self._nova_project_name = None
         self._nova_region_name = None
+        self._nova_user_domain_name = None
         self._ip_address = None
+        self._upgrade_package_password = None
+        self._upgrade_package_url = None
+        self._upgrade_package_username = None
+        self._upgrade_script_time_limit = None
         self._primary_nuage_controller = None
         self._vrs_config_id = None
         self._vrs_password = None
@@ -149,6 +193,7 @@ class NUVCenter(NURESTObject):
         self._ovf_url = None
         self._external_id = None
         
+        self.expose_attribute(local_name="vrs_configuration_time_limit", remote_name="VRSConfigurationTimeLimit", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="v_require_nuage_metadata", remote_name="vRequireNuageMetadata", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="password", remote_name="password", attribute_type=str, is_required=True, is_unique=False)
@@ -159,9 +204,14 @@ class NUVCenter(NURESTObject):
         self.expose_attribute(local_name="data_network_portgroup", remote_name="dataNetworkPortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="datapath_sync_timeout", remote_name="datapathSyncTimeout", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="secondary_nuage_controller", remote_name="secondaryNuageController", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="remote_syslog_server_ip", remote_name="remoteSyslogServerIP", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="remote_syslog_server_port", remote_name="remoteSyslogServerPort", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="remote_syslog_server_type", remote_name="remoteSyslogServerType", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'TCP', u'UDP'])
+        self.expose_attribute(local_name="generic_split_activation", remote_name="genericSplitActivation", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="separate_data_network", remote_name="separateDataNetwork", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="destination_mirror_port", remote_name="destinationMirrorPort", attribute_type=str, is_required=False, is_unique=False, choices=[u'ens160', u'ens161', u'ens224', u'ens256', u'no_mirror'])
         self.expose_attribute(local_name="metadata_server_ip", remote_name="metadataServerIP", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="metadata_server_listen_port", remote_name="metadataServerListenPort", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="metadata_server_port", remote_name="metadataServerPort", attribute_type=int, is_required=False, is_unique=False)
@@ -177,23 +227,36 @@ class NUVCenter(NURESTObject):
         self.expose_attribute(local_name="mgmt_gateway", remote_name="mgmtGateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="mgmt_network_portgroup", remote_name="mgmtNetworkPortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dhcp_relay_server", remote_name="dhcpRelayServer", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="mirror_network_portgroup", remote_name="mirrorNetworkPortgroup", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="disable_network_discovery", remote_name="disableNetworkDiscovery", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="site_id", remote_name="siteId", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="old_agency_name", remote_name="oldAgencyName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_data_dhcp", remote_name="allowDataDHCP", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_mgmt_dhcp", remote_name="allowMgmtDHCP", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="flow_eviction_threshold", remote_name="flowEvictionThreshold", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vm_network_portgroup", remote_name="vmNetworkPortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="connection_status", remote_name="connectionStatus", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="portgroup_metadata", remote_name="portgroupMetadata", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="host_level_management", remote_name="hostLevelManagement", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_client_version", remote_name="novaClientVersion", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="nova_identity_url_version", remote_name="novaIdentityURLVersion", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_service_auth_url", remote_name="novaMetadataServiceAuthUrl", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_service_endpoint", remote_name="novaMetadataServiceEndpoint", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_service_password", remote_name="novaMetadataServicePassword", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_service_tenant", remote_name="novaMetadataServiceTenant", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_service_username", remote_name="novaMetadataServiceUsername", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_shared_secret", remote_name="novaMetadataSharedSecret", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="nova_os_keystone_username", remote_name="novaOSKeystoneUsername", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="nova_project_domain_name", remote_name="novaProjectDomainName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="nova_project_name", remote_name="novaProjectName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_region_name", remote_name="novaRegionName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="nova_user_domain_name", remote_name="novaUserDomainName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="ip_address", remote_name="ipAddress", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="upgrade_package_password", remote_name="upgradePackagePassword", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="upgrade_package_url", remote_name="upgradePackageURL", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="upgrade_package_username", remote_name="upgradePackageUsername", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="upgrade_script_time_limit", remote_name="upgradeScriptTimeLimit", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="primary_nuage_controller", remote_name="primaryNuageController", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vrs_config_id", remote_name="vrsConfigID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vrs_password", remote_name="vrsPassword", attribute_type=str, is_required=False, is_unique=False)
@@ -234,13 +297,49 @@ class NUVCenter(NURESTObject):
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.vrs_address_ranges = NUVRSAddressRangesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
+        
+        self.vrs_redeploymentpolicies = NUVRSRedeploymentpoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.autodiscovereddatacenters = NUAutodiscovereddatacentersFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
 
         self._compute_args(**kwargs)
 
     # Properties
     
+    @property
+    def vrs_configuration_time_limit(self):
+        """ Get vrs_configuration_time_limit value.
+
+            Notes:
+                The maximum wait time limit in minutes to get VRS configured at cluster level
+
+                
+                This attribute is named `VRSConfigurationTimeLimit` in VSD API.
+                
+        """
+        return self._vrs_configuration_time_limit
+
+    @vrs_configuration_time_limit.setter
+    def vrs_configuration_time_limit(self, value):
+        """ Set vrs_configuration_time_limit value.
+
+            Notes:
+                The maximum wait time limit in minutes to get VRS configured at cluster level
+
+                
+                This attribute is named `VRSConfigurationTimeLimit` in VSD API.
+                
+        """
+        self._vrs_configuration_time_limit = value
+
+    
     @property
     def v_require_nuage_metadata(self):
         """ Get v_require_nuage_metadata value.
@@ -503,6 +602,114 @@ class NUVCenter(NURESTObject):
         self._secondary_nuage_controller = value
 
     
+    @property
+    def remote_syslog_server_ip(self):
+        """ Get remote_syslog_server_ip value.
+
+            Notes:
+                Remote syslog server IP
+
+                
+                This attribute is named `remoteSyslogServerIP` in VSD API.
+                
+        """
+        return self._remote_syslog_server_ip
+
+    @remote_syslog_server_ip.setter
+    def remote_syslog_server_ip(self, value):
+        """ Set remote_syslog_server_ip value.
+
+            Notes:
+                Remote syslog server IP
+
+                
+                This attribute is named `remoteSyslogServerIP` in VSD API.
+                
+        """
+        self._remote_syslog_server_ip = value
+
+    
+    @property
+    def remote_syslog_server_port(self):
+        """ Get remote_syslog_server_port value.
+
+            Notes:
+                Remote syslog server port
+
+                
+                This attribute is named `remoteSyslogServerPort` in VSD API.
+                
+        """
+        return self._remote_syslog_server_port
+
+    @remote_syslog_server_port.setter
+    def remote_syslog_server_port(self, value):
+        """ Set remote_syslog_server_port value.
+
+            Notes:
+                Remote syslog server port
+
+                
+                This attribute is named `remoteSyslogServerPort` in VSD API.
+                
+        """
+        self._remote_syslog_server_port = value
+
+    
+    @property
+    def remote_syslog_server_type(self):
+        """ Get remote_syslog_server_type value.
+
+            Notes:
+                Remote syslog server type (UDP/TCP)
+
+                
+                This attribute is named `remoteSyslogServerType` in VSD API.
+                
+        """
+        return self._remote_syslog_server_type
+
+    @remote_syslog_server_type.setter
+    def remote_syslog_server_type(self, value):
+        """ Set remote_syslog_server_type value.
+
+            Notes:
+                Remote syslog server type (UDP/TCP)
+
+                
+                This attribute is named `remoteSyslogServerType` in VSD API.
+                
+        """
+        self._remote_syslog_server_type = value
+
+    
+    @property
+    def generic_split_activation(self):
+        """ Get generic_split_activation value.
+
+            Notes:
+                Whether split-activation is needed from VRO
+
+                
+                This attribute is named `genericSplitActivation` in VSD API.
+                
+        """
+        return self._generic_split_activation
+
+    @generic_split_activation.setter
+    def generic_split_activation(self, value):
+        """ Set generic_split_activation value.
+
+            Notes:
+                Whether split-activation is needed from VRO
+
+                
+                This attribute is named `genericSplitActivation` in VSD API.
+                
+        """
+        self._generic_split_activation = value
+
+    
     @property
     def separate_data_network(self):
         """ Get separate_data_network value.
@@ -576,6 +783,33 @@ class NUVCenter(NURESTObject):
         self._description = value
 
     
+    @property
+    def destination_mirror_port(self):
+        """ Get destination_mirror_port value.
+
+            Notes:
+                Extra Vnic to mirror access port
+
+                
+                This attribute is named `destinationMirrorPort` in VSD API.
+                
+        """
+        return self._destination_mirror_port
+
+    @destination_mirror_port.setter
+    def destination_mirror_port(self, value):
+        """ Set destination_mirror_port value.
+
+            Notes:
+                Extra Vnic to mirror access port
+
+                
+                This attribute is named `destinationMirrorPort` in VSD API.
+                
+        """
+        self._destination_mirror_port = value
+
+    
     @property
     def metadata_server_ip(self):
         """ Get metadata_server_ip value.
@@ -981,6 +1215,60 @@ class NUVCenter(NURESTObject):
         self._dhcp_relay_server = value
 
     
+    @property
+    def mirror_network_portgroup(self):
+        """ Get mirror_network_portgroup value.
+
+            Notes:
+                Mirror Port Group Name
+
+                
+                This attribute is named `mirrorNetworkPortgroup` in VSD API.
+                
+        """
+        return self._mirror_network_portgroup
+
+    @mirror_network_portgroup.setter
+    def mirror_network_portgroup(self, value):
+        """ Set mirror_network_portgroup value.
+
+            Notes:
+                Mirror Port Group Name
+
+                
+                This attribute is named `mirrorNetworkPortgroup` in VSD API.
+                
+        """
+        self._mirror_network_portgroup = value
+
+    
+    @property
+    def disable_network_discovery(self):
+        """ Get disable_network_discovery value.
+
+            Notes:
+                disable Network Discovery (true - dont fetch portgroups from vcenter, false - fetch portgroups from vcenter)
+
+                
+                This attribute is named `disableNetworkDiscovery` in VSD API.
+                
+        """
+        return self._disable_network_discovery
+
+    @disable_network_discovery.setter
+    def disable_network_discovery(self, value):
+        """ Set disable_network_discovery value.
+
+            Notes:
+                disable Network Discovery (true - dont fetch portgroups from vcenter, false - fetch portgroups from vcenter)
+
+                
+                This attribute is named `disableNetworkDiscovery` in VSD API.
+                
+        """
+        self._disable_network_discovery = value
+
+    
     @property
     def site_id(self):
         """ Get site_id value.
@@ -1008,6 +1296,33 @@ class NUVCenter(NURESTObject):
         self._site_id = value
 
     
+    @property
+    def old_agency_name(self):
+        """ Get old_agency_name value.
+
+            Notes:
+                Old Agency Name
+
+                
+                This attribute is named `oldAgencyName` in VSD API.
+                
+        """
+        return self._old_agency_name
+
+    @old_agency_name.setter
+    def old_agency_name(self, value):
+        """ Set old_agency_name value.
+
+            Notes:
+                Old Agency Name
+
+                
+                This attribute is named `oldAgencyName` in VSD API.
+                
+        """
+        self._old_agency_name = value
+
+    
     @property
     def allow_data_dhcp(self):
         """ Get allow_data_dhcp value.
@@ -1143,6 +1458,33 @@ class NUVCenter(NURESTObject):
         self._entity_scope = value
 
     
+    @property
+    def connection_status(self):
+        """ Get connection_status value.
+
+            Notes:
+                VCenter connection status.
+
+                
+                This attribute is named `connectionStatus` in VSD API.
+                
+        """
+        return self._connection_status
+
+    @connection_status.setter
+    def connection_status(self, value):
+        """ Set connection_status value.
+
+            Notes:
+                VCenter connection status.
+
+                
+                This attribute is named `connectionStatus` in VSD API.
+                
+        """
+        self._connection_status = value
+
+    
     @property
     def portgroup_metadata(self):
         """ Get portgroup_metadata value.
@@ -1224,6 +1566,33 @@ class NUVCenter(NURESTObject):
         self._nova_client_version = value
 
     
+    @property
+    def nova_identity_url_version(self):
+        """ Get nova_identity_url_version value.
+
+            Notes:
+                Keystone identity version to use for the Nova metadata configuration on the VRS
+
+                
+                This attribute is named `novaIdentityURLVersion` in VSD API.
+                
+        """
+        return self._nova_identity_url_version
+
+    @nova_identity_url_version.setter
+    def nova_identity_url_version(self, value):
+        """ Set nova_identity_url_version value.
+
+            Notes:
+                Keystone identity version to use for the Nova metadata configuration on the VRS
+
+                
+                This attribute is named `novaIdentityURLVersion` in VSD API.
+                
+        """
+        self._nova_identity_url_version = value
+
+    
     @property
     def nova_metadata_service_auth_url(self):
         """ Get nova_metadata_service_auth_url value.
@@ -1386,6 +1755,87 @@ class NUVCenter(NURESTObject):
         self._nova_metadata_shared_secret = value
 
     
+    @property
+    def nova_os_keystone_username(self):
+        """ Get nova_os_keystone_username value.
+
+            Notes:
+                Keystone username used by nova
+
+                
+                This attribute is named `novaOSKeystoneUsername` in VSD API.
+                
+        """
+        return self._nova_os_keystone_username
+
+    @nova_os_keystone_username.setter
+    def nova_os_keystone_username(self, value):
+        """ Set nova_os_keystone_username value.
+
+            Notes:
+                Keystone username used by nova
+
+                
+                This attribute is named `novaOSKeystoneUsername` in VSD API.
+                
+        """
+        self._nova_os_keystone_username = value
+
+    
+    @property
+    def nova_project_domain_name(self):
+        """ Get nova_project_domain_name value.
+
+            Notes:
+                Name of the project that the Nova service uses, can be determined from the nova.conf on the OpenStack controller
+
+                
+                This attribute is named `novaProjectDomainName` in VSD API.
+                
+        """
+        return self._nova_project_domain_name
+
+    @nova_project_domain_name.setter
+    def nova_project_domain_name(self, value):
+        """ Set nova_project_domain_name value.
+
+            Notes:
+                Name of the project that the Nova service uses, can be determined from the nova.conf on the OpenStack controller
+
+                
+                This attribute is named `novaProjectDomainName` in VSD API.
+                
+        """
+        self._nova_project_domain_name = value
+
+    
+    @property
+    def nova_project_name(self):
+        """ Get nova_project_name value.
+
+            Notes:
+                Name of the default Nova project (example: services)
+
+                
+                This attribute is named `novaProjectName` in VSD API.
+                
+        """
+        return self._nova_project_name
+
+    @nova_project_name.setter
+    def nova_project_name(self, value):
+        """ Set nova_project_name value.
+
+            Notes:
+                Name of the default Nova project (example: services)
+
+                
+                This attribute is named `novaProjectName` in VSD API.
+                
+        """
+        self._nova_project_name = value
+
+    
     @property
     def nova_region_name(self):
         """ Get nova_region_name value.
@@ -1413,6 +1863,33 @@ class NUVCenter(NURESTObject):
         self._nova_region_name = value
 
     
+    @property
+    def nova_user_domain_name(self):
+        """ Get nova_user_domain_name value.
+
+            Notes:
+                Name of the user domain used by the Nova service, can be determined from the nova.conf on the OpenStack controller
+
+                
+                This attribute is named `novaUserDomainName` in VSD API.
+                
+        """
+        return self._nova_user_domain_name
+
+    @nova_user_domain_name.setter
+    def nova_user_domain_name(self, value):
+        """ Set nova_user_domain_name value.
+
+            Notes:
+                Name of the user domain used by the Nova service, can be determined from the nova.conf on the OpenStack controller
+
+                
+                This attribute is named `novaUserDomainName` in VSD API.
+                
+        """
+        self._nova_user_domain_name = value
+
+    
     @property
     def ip_address(self):
         """ Get ip_address value.
@@ -1440,6 +1917,114 @@ class NUVCenter(NURESTObject):
         self._ip_address = value
 
     
+    @property
+    def upgrade_package_password(self):
+        """ Get upgrade_package_password value.
+
+            Notes:
+                Upgrade package password used for script based upgrades
+
+                
+                This attribute is named `upgradePackagePassword` in VSD API.
+                
+        """
+        return self._upgrade_package_password
+
+    @upgrade_package_password.setter
+    def upgrade_package_password(self, value):
+        """ Set upgrade_package_password value.
+
+            Notes:
+                Upgrade package password used for script based upgrades
+
+                
+                This attribute is named `upgradePackagePassword` in VSD API.
+                
+        """
+        self._upgrade_package_password = value
+
+    
+    @property
+    def upgrade_package_url(self):
+        """ Get upgrade_package_url value.
+
+            Notes:
+                Upgrade package URLused for script based upgrades
+
+                
+                This attribute is named `upgradePackageURL` in VSD API.
+                
+        """
+        return self._upgrade_package_url
+
+    @upgrade_package_url.setter
+    def upgrade_package_url(self, value):
+        """ Set upgrade_package_url value.
+
+            Notes:
+                Upgrade package URLused for script based upgrades
+
+                
+                This attribute is named `upgradePackageURL` in VSD API.
+                
+        """
+        self._upgrade_package_url = value
+
+    
+    @property
+    def upgrade_package_username(self):
+        """ Get upgrade_package_username value.
+
+            Notes:
+                Upgrade package username used for script based upgrades
+
+                
+                This attribute is named `upgradePackageUsername` in VSD API.
+                
+        """
+        return self._upgrade_package_username
+
+    @upgrade_package_username.setter
+    def upgrade_package_username(self, value):
+        """ Set upgrade_package_username value.
+
+            Notes:
+                Upgrade package username used for script based upgrades
+
+                
+                This attribute is named `upgradePackageUsername` in VSD API.
+                
+        """
+        self._upgrade_package_username = value
+
+    
+    @property
+    def upgrade_script_time_limit(self):
+        """ Get upgrade_script_time_limit value.
+
+            Notes:
+                Time limit for the patch based upgrade functionality. If the upgrade process of a VRS has not returned a success or failure status within this time limit, the status will be changed to TIMEOUT. Specified in seconds
+
+                
+                This attribute is named `upgradeScriptTimeLimit` in VSD API.
+                
+        """
+        return self._upgrade_script_time_limit
+
+    @upgrade_script_time_limit.setter
+    def upgrade_script_time_limit(self, value):
+        """ Set upgrade_script_time_limit value.
+
+            Notes:
+                Time limit for the patch based upgrade functionality. If the upgrade process of a VRS has not returned a success or failure status within this time limit, the status will be changed to TIMEOUT. Specified in seconds
+
+                
+                This attribute is named `upgradeScriptTimeLimit` in VSD API.
+                
+        """
+        self._upgrade_script_time_limit = value
+
+    
     @property
     def primary_nuage_controller(self):
         """ Get primary_nuage_controller value.
