@@ -36,8 +36,17 @@ from .fetchers import NUMetadatasFetcher
 from .fetchers import NUGlobalMetadatasFetcher
 
 
+from .fetchers import NUJobsFetcher
+
+
 from .fetchers import NUVRSAddressRangesFetcher
 
+
+from .fetchers import NUVRSRedeploymentpoliciesFetcher
+
+
+from .fetchers import NUAutoDiscoverHypervisorFromClustersFetcher
+
 from bambou import NURESTObject
 
 
@@ -54,10 +63,26 @@ class NUVCenterCluster(NURESTObject):
     
     ## Constants
     
+    CONST_REMOTE_SYSLOG_SERVER_TYPE_NONE = "NONE"
+    
+    CONST_REMOTE_SYSLOG_SERVER_TYPE_UDP = "UDP"
+    
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
+    CONST_DESTINATION_MIRROR_PORT_ENS160 = "ens160"
+    
+    CONST_DESTINATION_MIRROR_PORT_ENS161 = "ens161"
+    
+    CONST_DESTINATION_MIRROR_PORT_NO_MIRROR = "no_mirror"
+    
+    CONST_REMOTE_SYSLOG_SERVER_TYPE_TCP = "TCP"
+    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
+    CONST_DESTINATION_MIRROR_PORT_ENS224 = "ens224"
+    
+    CONST_DESTINATION_MIRROR_PORT_ENS256 = "ens256"
+    
     
 
     def __init__(self, **kwargs):
@@ -77,18 +102,27 @@ class NUVCenterCluster(NURESTObject):
 
         # Read/Write Attributes
         
+        self._vrs_configuration_time_limit = None
         self._v_require_nuage_metadata = None
         self._name = None
+        self._managed_object_id = None
         self._last_updated_by = None
         self._data_dns1 = None
         self._data_dns2 = None
         self._data_gateway = None
         self._data_network_portgroup = None
         self._datapath_sync_timeout = None
+        self._scope = None
         self._secondary_nuage_controller = None
+        self._deleted_from_vcenter_data_center = None
+        self._remote_syslog_server_ip = None
+        self._remote_syslog_server_port = None
+        self._remote_syslog_server_type = None
+        self._generic_split_activation = None
         self._separate_data_network = None
         self._personality = None
         self._description = None
+        self._destination_mirror_port = None
         self._metadata_server_ip = None
         self._metadata_server_listen_port = None
         self._metadata_server_port = None
@@ -104,6 +138,7 @@ class NUVCenterCluster(NURESTObject):
         self._mgmt_gateway = None
         self._mgmt_network_portgroup = None
         self._dhcp_relay_server = None
+        self._mirror_network_portgroup = None
         self._site_id = None
         self._allow_data_dhcp = None
         self._allow_mgmt_dhcp = None
@@ -112,17 +147,27 @@ class NUVCenterCluster(NURESTObject):
         self._entity_scope = None
         self._portgroup_metadata = None
         self._nova_client_version = None
+        self._nova_identity_url_version = None
         self._nova_metadata_service_auth_url = None
         self._nova_metadata_service_endpoint = None
         self._nova_metadata_service_password = None
         self._nova_metadata_service_tenant = None
         self._nova_metadata_service_username = None
         self._nova_metadata_shared_secret = None
+        self._nova_os_keystone_username = None
+        self._nova_project_domain_name = None
+        self._nova_project_name = None
         self._nova_region_name = None
+        self._nova_user_domain_name = None
+        self._upgrade_package_password = None
+        self._upgrade_package_url = None
+        self._upgrade_package_username = None
+        self._upgrade_script_time_limit = None
         self._primary_nuage_controller = None
         self._vrs_password = None
         self._vrs_user_name = None
         self._assoc_vcenter_data_center_id = None
+        self._assoc_vcenter_id = None
         self._static_route = None
         self._static_route_gateway = None
         self._static_route_netmask = None
@@ -139,20 +184,30 @@ class NUVCenterCluster(NURESTObject):
         self._multicast_send_interface_netmask = None
         self._multicast_source_portgroup = None
         self._customized_script_url = None
+        self._ovf_url = None
         self._external_id = None
         
+        self.expose_attribute(local_name="vrs_configuration_time_limit", remote_name="VRSConfigurationTimeLimit", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="v_require_nuage_metadata", remote_name="vRequireNuageMetadata", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="managed_object_id", remote_name="managedObjectID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_dns1", remote_name="dataDNS1", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_dns2", remote_name="dataDNS2", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_gateway", remote_name="dataGateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_network_portgroup", remote_name="dataNetworkPortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="datapath_sync_timeout", remote_name="datapathSyncTimeout", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="scope", remote_name="scope", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="secondary_nuage_controller", remote_name="secondaryNuageController", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="deleted_from_vcenter_data_center", remote_name="deletedFromVCenterDataCenter", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="remote_syslog_server_ip", remote_name="remoteSyslogServerIP", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="remote_syslog_server_port", remote_name="remoteSyslogServerPort", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="remote_syslog_server_type", remote_name="remoteSyslogServerType", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'TCP', u'UDP'])
+        self.expose_attribute(local_name="generic_split_activation", remote_name="genericSplitActivation", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="separate_data_network", remote_name="separateDataNetwork", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="destination_mirror_port", remote_name="destinationMirrorPort", attribute_type=str, is_required=False, is_unique=False, choices=[u'ens160', u'ens161', u'ens224', u'ens256', u'no_mirror'])
         self.expose_attribute(local_name="metadata_server_ip", remote_name="metadataServerIP", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="metadata_server_listen_port", remote_name="metadataServerListenPort", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="metadata_server_port", remote_name="metadataServerPort", attribute_type=int, is_required=False, is_unique=False)
@@ -168,6 +223,7 @@ class NUVCenterCluster(NURESTObject):
         self.expose_attribute(local_name="mgmt_gateway", remote_name="mgmtGateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="mgmt_network_portgroup", remote_name="mgmtNetworkPortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dhcp_relay_server", remote_name="dhcpRelayServer", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="mirror_network_portgroup", remote_name="mirrorNetworkPortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="site_id", remote_name="siteId", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_data_dhcp", remote_name="allowDataDHCP", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_mgmt_dhcp", remote_name="allowMgmtDHCP", attribute_type=bool, is_required=False, is_unique=False)
@@ -176,17 +232,27 @@ class NUVCenterCluster(NURESTObject):
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="portgroup_metadata", remote_name="portgroupMetadata", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_client_version", remote_name="novaClientVersion", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="nova_identity_url_version", remote_name="novaIdentityURLVersion", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_service_auth_url", remote_name="novaMetadataServiceAuthUrl", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_service_endpoint", remote_name="novaMetadataServiceEndpoint", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_service_password", remote_name="novaMetadataServicePassword", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_service_tenant", remote_name="novaMetadataServiceTenant", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_service_username", remote_name="novaMetadataServiceUsername", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_metadata_shared_secret", remote_name="novaMetadataSharedSecret", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="nova_os_keystone_username", remote_name="novaOSKeystoneUsername", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="nova_project_domain_name", remote_name="novaProjectDomainName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="nova_project_name", remote_name="novaProjectName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_region_name", remote_name="novaRegionName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="nova_user_domain_name", remote_name="novaUserDomainName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="upgrade_package_password", remote_name="upgradePackagePassword", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="upgrade_package_url", remote_name="upgradePackageURL", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="upgrade_package_username", remote_name="upgradePackageUsername", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="upgrade_script_time_limit", remote_name="upgradeScriptTimeLimit", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="primary_nuage_controller", remote_name="primaryNuageController", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vrs_password", remote_name="vrsPassword", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vrs_user_name", remote_name="vrsUserName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="assoc_vcenter_data_center_id", remote_name="assocVCenterDataCenterID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="assoc_vcenter_id", remote_name="assocVCenterID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="static_route", remote_name="staticRoute", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="static_route_gateway", remote_name="staticRouteGateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="static_route_netmask", remote_name="staticRouteNetmask", attribute_type=str, is_required=False, is_unique=False)
@@ -203,6 +269,7 @@ class NUVCenterCluster(NURESTObject):
         self.expose_attribute(local_name="multicast_send_interface_netmask", remote_name="multicastSendInterfaceNetmask", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast_source_portgroup", remote_name="multicastSourcePortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="customized_script_url", remote_name="customizedScriptURL", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ovf_url", remote_name="ovfURL", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -218,13 +285,49 @@ class NUVCenterCluster(NURESTObject):
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.vrs_address_ranges = NUVRSAddressRangesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
+        
+        self.vrs_redeploymentpolicies = NUVRSRedeploymentpoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.auto_discover_hypervisor_from_clusters = NUAutoDiscoverHypervisorFromClustersFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
 
         self._compute_args(**kwargs)
 
     # Properties
     
+    @property
+    def vrs_configuration_time_limit(self):
+        """ Get vrs_configuration_time_limit value.
+
+            Notes:
+                The maximum wait time limit in minutes to get VRS configured at cluster level
+
+                
+                This attribute is named `VRSConfigurationTimeLimit` in VSD API.
+                
+        """
+        return self._vrs_configuration_time_limit
+
+    @vrs_configuration_time_limit.setter
+    def vrs_configuration_time_limit(self, value):
+        """ Set vrs_configuration_time_limit value.
+
+            Notes:
+                The maximum wait time limit in minutes to get VRS configured at cluster level
+
+                
+                This attribute is named `VRSConfigurationTimeLimit` in VSD API.
+                
+        """
+        self._vrs_configuration_time_limit = value
+
+    
     @property
     def v_require_nuage_metadata(self):
         """ Get v_require_nuage_metadata value.
@@ -275,6 +378,33 @@ class NUVCenterCluster(NURESTObject):
         self._name = value
 
     
+    @property
+    def managed_object_id(self):
+        """ Get managed_object_id value.
+
+            Notes:
+                VCenter Managed Object ID of the Cluster.
+
+                
+                This attribute is named `managedObjectID` in VSD API.
+                
+        """
+        return self._managed_object_id
+
+    @managed_object_id.setter
+    def managed_object_id(self, value):
+        """ Set managed_object_id value.
+
+            Notes:
+                VCenter Managed Object ID of the Cluster.
+
+                
+                This attribute is named `managedObjectID` in VSD API.
+                
+        """
+        self._managed_object_id = value
+
+    
     @property
     def last_updated_by(self):
         """ Get last_updated_by value.
@@ -437,6 +567,29 @@ class NUVCenterCluster(NURESTObject):
         self._datapath_sync_timeout = value
 
     
+    @property
+    def scope(self):
+        """ Get scope value.
+
+            Notes:
+                Cluster in scope or not in scope.
+
+                
+        """
+        return self._scope
+
+    @scope.setter
+    def scope(self, value):
+        """ Set scope value.
+
+            Notes:
+                Cluster in scope or not in scope.
+
+                
+        """
+        self._scope = value
+
+    
     @property
     def secondary_nuage_controller(self):
         """ Get secondary_nuage_controller value.
@@ -464,6 +617,141 @@ class NUVCenterCluster(NURESTObject):
         self._secondary_nuage_controller = value
 
     
+    @property
+    def deleted_from_vcenter_data_center(self):
+        """ Get deleted_from_vcenter_data_center value.
+
+            Notes:
+                Set to true if the cluster is deleted from Vcenter
+
+                
+                This attribute is named `deletedFromVCenterDataCenter` in VSD API.
+                
+        """
+        return self._deleted_from_vcenter_data_center
+
+    @deleted_from_vcenter_data_center.setter
+    def deleted_from_vcenter_data_center(self, value):
+        """ Set deleted_from_vcenter_data_center value.
+
+            Notes:
+                Set to true if the cluster is deleted from Vcenter
+
+                
+                This attribute is named `deletedFromVCenterDataCenter` in VSD API.
+                
+        """
+        self._deleted_from_vcenter_data_center = value
+
+    
+    @property
+    def remote_syslog_server_ip(self):
+        """ Get remote_syslog_server_ip value.
+
+            Notes:
+                Remote syslog server IP
+
+                
+                This attribute is named `remoteSyslogServerIP` in VSD API.
+                
+        """
+        return self._remote_syslog_server_ip
+
+    @remote_syslog_server_ip.setter
+    def remote_syslog_server_ip(self, value):
+        """ Set remote_syslog_server_ip value.
+
+            Notes:
+                Remote syslog server IP
+
+                
+                This attribute is named `remoteSyslogServerIP` in VSD API.
+                
+        """
+        self._remote_syslog_server_ip = value
+
+    
+    @property
+    def remote_syslog_server_port(self):
+        """ Get remote_syslog_server_port value.
+
+            Notes:
+                Remote syslog server port
+
+                
+                This attribute is named `remoteSyslogServerPort` in VSD API.
+                
+        """
+        return self._remote_syslog_server_port
+
+    @remote_syslog_server_port.setter
+    def remote_syslog_server_port(self, value):
+        """ Set remote_syslog_server_port value.
+
+            Notes:
+                Remote syslog server port
+
+                
+                This attribute is named `remoteSyslogServerPort` in VSD API.
+                
+        """
+        self._remote_syslog_server_port = value
+
+    
+    @property
+    def remote_syslog_server_type(self):
+        """ Get remote_syslog_server_type value.
+
+            Notes:
+                Remote syslog server type (UDP/TCP)
+
+                
+                This attribute is named `remoteSyslogServerType` in VSD API.
+                
+        """
+        return self._remote_syslog_server_type
+
+    @remote_syslog_server_type.setter
+    def remote_syslog_server_type(self, value):
+        """ Set remote_syslog_server_type value.
+
+            Notes:
+                Remote syslog server type (UDP/TCP)
+
+                
+                This attribute is named `remoteSyslogServerType` in VSD API.
+                
+        """
+        self._remote_syslog_server_type = value
+
+    
+    @property
+    def generic_split_activation(self):
+        """ Get generic_split_activation value.
+
+            Notes:
+                Whether split-activation is needed from VRO
+
+                
+                This attribute is named `genericSplitActivation` in VSD API.
+                
+        """
+        return self._generic_split_activation
+
+    @generic_split_activation.setter
+    def generic_split_activation(self, value):
+        """ Set generic_split_activation value.
+
+            Notes:
+                Whether split-activation is needed from VRO
+
+                
+                This attribute is named `genericSplitActivation` in VSD API.
+                
+        """
+        self._generic_split_activation = value
+
+    
     @property
     def separate_data_network(self):
         """ Get separate_data_network value.
@@ -537,6 +825,33 @@ class NUVCenterCluster(NURESTObject):
         self._description = value
 
     
+    @property
+    def destination_mirror_port(self):
+        """ Get destination_mirror_port value.
+
+            Notes:
+                Extra Vnic to mirror access port
+
+                
+                This attribute is named `destinationMirrorPort` in VSD API.
+                
+        """
+        return self._destination_mirror_port
+
+    @destination_mirror_port.setter
+    def destination_mirror_port(self, value):
+        """ Set destination_mirror_port value.
+
+            Notes:
+                Extra Vnic to mirror access port
+
+                
+                This attribute is named `destinationMirrorPort` in VSD API.
+                
+        """
+        self._destination_mirror_port = value
+
+    
     @property
     def metadata_server_ip(self):
         """ Get metadata_server_ip value.
@@ -942,6 +1257,33 @@ class NUVCenterCluster(NURESTObject):
         self._dhcp_relay_server = value
 
     
+    @property
+    def mirror_network_portgroup(self):
+        """ Get mirror_network_portgroup value.
+
+            Notes:
+                Mirror Port Group Name
+
+                
+                This attribute is named `mirrorNetworkPortgroup` in VSD API.
+                
+        """
+        return self._mirror_network_portgroup
+
+    @mirror_network_portgroup.setter
+    def mirror_network_portgroup(self, value):
+        """ Set mirror_network_portgroup value.
+
+            Notes:
+                Mirror Port Group Name
+
+                
+                This attribute is named `mirrorNetworkPortgroup` in VSD API.
+                
+        """
+        self._mirror_network_portgroup = value
+
+    
     @property
     def site_id(self):
         """ Get site_id value.
@@ -1158,6 +1500,33 @@ class NUVCenterCluster(NURESTObject):
         self._nova_client_version = value
 
     
+    @property
+    def nova_identity_url_version(self):
+        """ Get nova_identity_url_version value.
+
+            Notes:
+                Keystone identity version to use for the Nova metadata configuration on the VRS
+
+                
+                This attribute is named `novaIdentityURLVersion` in VSD API.
+                
+        """
+        return self._nova_identity_url_version
+
+    @nova_identity_url_version.setter
+    def nova_identity_url_version(self, value):
+        """ Set nova_identity_url_version value.
+
+            Notes:
+                Keystone identity version to use for the Nova metadata configuration on the VRS
+
+                
+                This attribute is named `novaIdentityURLVersion` in VSD API.
+                
+        """
+        self._nova_identity_url_version = value
+
+    
     @property
     def nova_metadata_service_auth_url(self):
         """ Get nova_metadata_service_auth_url value.
@@ -1320,6 +1689,87 @@ class NUVCenterCluster(NURESTObject):
         self._nova_metadata_shared_secret = value
 
     
+    @property
+    def nova_os_keystone_username(self):
+        """ Get nova_os_keystone_username value.
+
+            Notes:
+                Keystone username used by nova
+
+                
+                This attribute is named `novaOSKeystoneUsername` in VSD API.
+                
+        """
+        return self._nova_os_keystone_username
+
+    @nova_os_keystone_username.setter
+    def nova_os_keystone_username(self, value):
+        """ Set nova_os_keystone_username value.
+
+            Notes:
+                Keystone username used by nova
+
+                
+                This attribute is named `novaOSKeystoneUsername` in VSD API.
+                
+        """
+        self._nova_os_keystone_username = value
+
+    
+    @property
+    def nova_project_domain_name(self):
+        """ Get nova_project_domain_name value.
+
+            Notes:
+                Name of the project that the Nova service uses, can be determined from the nova.conf on the OpenStack controller
+
+                
+                This attribute is named `novaProjectDomainName` in VSD API.
+                
+        """
+        return self._nova_project_domain_name
+
+    @nova_project_domain_name.setter
+    def nova_project_domain_name(self, value):
+        """ Set nova_project_domain_name value.
+
+            Notes:
+                Name of the project that the Nova service uses, can be determined from the nova.conf on the OpenStack controller
+
+                
+                This attribute is named `novaProjectDomainName` in VSD API.
+                
+        """
+        self._nova_project_domain_name = value
+
+    
+    @property
+    def nova_project_name(self):
+        """ Get nova_project_name value.
+
+            Notes:
+                Name of the default Nova project (example: services)
+
+                
+                This attribute is named `novaProjectName` in VSD API.
+                
+        """
+        return self._nova_project_name
+
+    @nova_project_name.setter
+    def nova_project_name(self, value):
+        """ Set nova_project_name value.
+
+            Notes:
+                Name of the default Nova project (example: services)
+
+                
+                This attribute is named `novaProjectName` in VSD API.
+                
+        """
+        self._nova_project_name = value
+
+    
     @property
     def nova_region_name(self):
         """ Get nova_region_name value.
@@ -1347,6 +1797,141 @@ class NUVCenterCluster(NURESTObject):
         self._nova_region_name = value
 
     
+    @property
+    def nova_user_domain_name(self):
+        """ Get nova_user_domain_name value.
+
+            Notes:
+                Name of the user domain used by the Nova service, can be determined from the nova.conf on the OpenStack controller
+
+                
+                This attribute is named `novaUserDomainName` in VSD API.
+                
+        """
+        return self._nova_user_domain_name
+
+    @nova_user_domain_name.setter
+    def nova_user_domain_name(self, value):
+        """ Set nova_user_domain_name value.
+
+            Notes:
+                Name of the user domain used by the Nova service, can be determined from the nova.conf on the OpenStack controller
+
+                
+                This attribute is named `novaUserDomainName` in VSD API.
+                
+        """
+        self._nova_user_domain_name = value
+
+    
+    @property
+    def upgrade_package_password(self):
+        """ Get upgrade_package_password value.
+
+            Notes:
+                Upgrade package password used for script based upgrades
+
+                
+                This attribute is named `upgradePackagePassword` in VSD API.
+                
+        """
+        return self._upgrade_package_password
+
+    @upgrade_package_password.setter
+    def upgrade_package_password(self, value):
+        """ Set upgrade_package_password value.
+
+            Notes:
+                Upgrade package password used for script based upgrades
+
+                
+                This attribute is named `upgradePackagePassword` in VSD API.
+                
+        """
+        self._upgrade_package_password = value
+
+    
+    @property
+    def upgrade_package_url(self):
+        """ Get upgrade_package_url value.
+
+            Notes:
+                Upgrade package URLused for script based upgrades
+
+                
+                This attribute is named `upgradePackageURL` in VSD API.
+                
+        """
+        return self._upgrade_package_url
+
+    @upgrade_package_url.setter
+    def upgrade_package_url(self, value):
+        """ Set upgrade_package_url value.
+
+            Notes:
+                Upgrade package URLused for script based upgrades
+
+                
+                This attribute is named `upgradePackageURL` in VSD API.
+                
+        """
+        self._upgrade_package_url = value
+
+    
+    @property
+    def upgrade_package_username(self):
+        """ Get upgrade_package_username value.
+
+            Notes:
+                Upgrade package username used for script based upgrades
+
+                
+                This attribute is named `upgradePackageUsername` in VSD API.
+                
+        """
+        return self._upgrade_package_username
+
+    @upgrade_package_username.setter
+    def upgrade_package_username(self, value):
+        """ Set upgrade_package_username value.
+
+            Notes:
+                Upgrade package username used for script based upgrades
+
+                
+                This attribute is named `upgradePackageUsername` in VSD API.
+                
+        """
+        self._upgrade_package_username = value
+
+    
+    @property
+    def upgrade_script_time_limit(self):
+        """ Get upgrade_script_time_limit value.
+
+            Notes:
+                Time limit for the patch based upgrade functionality. If the upgrade process of a VRS has not returned a success or failure status within this time limit, the status will be changed to TIMEOUT. Specified in seconds
+
+                
+                This attribute is named `upgradeScriptTimeLimit` in VSD API.
+                
+        """
+        return self._upgrade_script_time_limit
+
+    @upgrade_script_time_limit.setter
+    def upgrade_script_time_limit(self, value):
+        """ Set upgrade_script_time_limit value.
+
+            Notes:
+                Time limit for the patch based upgrade functionality. If the upgrade process of a VRS has not returned a success or failure status within this time limit, the status will be changed to TIMEOUT. Specified in seconds
+
+                
+                This attribute is named `upgradeScriptTimeLimit` in VSD API.
+                
+        """
+        self._upgrade_script_time_limit = value
+
+    
     @property
     def primary_nuage_controller(self):
         """ Get primary_nuage_controller value.
@@ -1455,6 +2040,33 @@ class NUVCenterCluster(NURESTObject):
         self._assoc_vcenter_data_center_id = value
 
     
+    @property
+    def assoc_vcenter_id(self):
+        """ Get assoc_vcenter_id value.
+
+            Notes:
+                ID of the associated VCenter.
+
+                
+                This attribute is named `assocVCenterID` in VSD API.
+                
+        """
+        return self._assoc_vcenter_id
+
+    @assoc_vcenter_id.setter
+    def assoc_vcenter_id(self, value):
+        """ Set assoc_vcenter_id value.
+
+            Notes:
+                ID of the associated VCenter.
+
+                
+                This attribute is named `assocVCenterID` in VSD API.
+                
+        """
+        self._assoc_vcenter_id = value
+
+    
     @property
     def static_route(self):
         """ Get static_route value.
@@ -1883,6 +2495,33 @@ class NUVCenterCluster(NURESTObject):
         self._customized_script_url = value
 
     
+    @property
+    def ovf_url(self):
+        """ Get ovf_url value.
+
+            Notes:
+                ovf url
+
+                
+                This attribute is named `ovfURL` in VSD API.
+                
+        """
+        return self._ovf_url
+
+    @ovf_url.setter
+    def ovf_url(self, value):
+        """ Set ovf_url value.
+
+            Notes:
+                ovf url
+
+                
+                This attribute is named `ovfURL` in VSD API.
+                
+        """
+        self._ovf_url = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
