@@ -45,6 +45,9 @@ from .fetchers import NUJobsFetcher
 from .fetchers import NUMonitoringPortsFetcher
 
 
+from .fetchers import NUContainersFetcher
+
+
 from .fetchers import NUVPortsFetcher
 
 
@@ -75,30 +78,36 @@ class NUVRS(NURESTObject):
     
     ## Constants
     
-    CONST_STATUS_DOWN = "DOWN"
+    CONST_VSC_CONFIG_STATE_PRIMARY = "PRIMARY"
     
-    CONST_CLUSTER_NODE_ROLE_NONE = "NONE"
+    CONST_STATUS_DOWN = "DOWN"
     
     CONST_HYPERVISOR_CONNECTION_STATE_UP = "UP"
     
-    CONST_HYPERVISOR_CONNECTION_STATE_ADMIN_DOWN = "ADMIN_DOWN"
+    CONST_PERSONALITY_NUAGE_210_WBX_32_Q = "NUAGE_210_WBX_32_Q"
     
     CONST_PERSONALITY_NONE = "NONE"
     
-    CONST_HYPERVISOR_CONNECTION_STATE_DOWN = "DOWN"
+    CONST_CLUSTER_NODE_ROLE_NONE = "NONE"
     
     CONST_CLUSTER_NODE_ROLE_SECONDARY = "SECONDARY"
     
     CONST_PERSONALITY_VRS = "VRS"
     
+    CONST_HYPERVISOR_CONNECTION_STATE_ADMIN_DOWN = "ADMIN_DOWN"
+    
     CONST_PERSONALITY_NSG = "NSG"
     
     CONST_ROLE_MASTER = "MASTER"
     
     CONST_STATUS_ADMIN_DOWN = "ADMIN_DOWN"
     
+    CONST_HYPERVISOR_CONNECTION_STATE_DOWN = "DOWN"
+    
     CONST_ROLE_SLAVE = "SLAVE"
     
+    CONST_LICENSED_STATE_LICENSED = "LICENSED"
+    
     CONST_PERSONALITY_HARDWARE_VTEP = "HARDWARE_VTEP"
     
     CONST_JSONRPC_CONNECTION_STATE_UP = "UP"
@@ -107,10 +116,14 @@ class NUVRS(NURESTObject):
     
     CONST_STATUS_UP = "UP"
     
+    CONST_PERSONALITY_NUAGE_210_WBX_48_S = "NUAGE_210_WBX_48_S"
+    
     CONST_PERSONALITY_VRSG = "VRSG"
     
     CONST_CLUSTER_NODE_ROLE_PRIMARY = "PRIMARY"
     
+    CONST_VSC_CONFIG_STATE_SECONDARY = "SECONDARY"
+    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
     CONST_JSONRPC_CONNECTION_STATE_DOWN = "DOWN"
@@ -119,6 +132,12 @@ class NUVRS(NURESTObject):
     
     CONST_ROLE_NONE = "NONE"
     
+    CONST_VSC_CURRENT_STATE_SECONDARY = "SECONDARY"
+    
+    CONST_VSC_CURRENT_STATE_PRIMARY = "PRIMARY"
+    
+    CONST_LICENSED_STATE_UNLICENSED = "UNLICENSED"
+    
     
 
     def __init__(self, **kwargs):
@@ -155,17 +174,26 @@ class NUVRS(NURESTObject):
         self._personality = None
         self._description = None
         self._messages = None
+        self._revert_behavior_enabled = None
+        self._revert_completed = None
+        self._revert_count = None
+        self._revert_failed_count = None
+        self._licensed_state = None
         self._disks = None
         self._cluster_node_role = None
         self._entity_scope = None
         self._location = None
         self._role = None
         self._uptime = None
+        self._primary_vsc_connection_lost = None
         self._product_version = None
         self._is_resilient = None
+        self._vsc_config_state = None
+        self._vsc_current_state = None
         self._status = None
         self._multi_nic_vport_enabled = None
         self._number_of_bridge_interfaces = None
+        self._number_of_containers = None
         self._number_of_host_interfaces = None
         self._number_of_virtual_machines = None
         self._current_cpuusage = None
@@ -193,20 +221,29 @@ class NUVRS(NURESTObject):
         self.expose_attribute(local_name="peak_cpuusage", remote_name="peakCPUUsage", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peak_memory_usage", remote_name="peakMemoryUsage", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peer", remote_name="peer", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'HARDWARE_VTEP', u'NONE', u'NSG', u'VRS', u'VRSG'])
+        self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'HARDWARE_VTEP', u'NONE', u'NSG', u'NUAGE_210_WBX_32_Q', u'NUAGE_210_WBX_48_S', u'VRS', u'VRSG'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="messages", remote_name="messages", attribute_type=list, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="revert_behavior_enabled", remote_name="revertBehaviorEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="revert_completed", remote_name="revertCompleted", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="revert_count", remote_name="revertCount", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="revert_failed_count", remote_name="revertFailedCount", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="licensed_state", remote_name="licensedState", attribute_type=str, is_required=False, is_unique=False, choices=[u'LICENSED', u'UNLICENSED'])
         self.expose_attribute(local_name="disks", remote_name="disks", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="cluster_node_role", remote_name="clusterNodeRole", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'PRIMARY', u'SECONDARY'])
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="location", remote_name="location", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="role", remote_name="role", attribute_type=str, is_required=False, is_unique=False, choices=[u'MASTER', u'NONE', u'SLAVE'])
         self.expose_attribute(local_name="uptime", remote_name="uptime", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="primary_vsc_connection_lost", remote_name="primaryVSCConnectionLost", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="product_version", remote_name="productVersion", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="is_resilient", remote_name="isResilient", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="vsc_config_state", remote_name="vscConfigState", attribute_type=str, is_required=False, is_unique=False, choices=[u'PRIMARY', u'SECONDARY'])
+        self.expose_attribute(local_name="vsc_current_state", remote_name="vscCurrentState", attribute_type=str, is_required=False, is_unique=False, choices=[u'PRIMARY', u'SECONDARY'])
         self.expose_attribute(local_name="status", remote_name="status", attribute_type=str, is_required=False, is_unique=False, choices=[u'ADMIN_DOWN', u'DOWN', u'UP'])
         self.expose_attribute(local_name="multi_nic_vport_enabled", remote_name="multiNICVPortEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="number_of_bridge_interfaces", remote_name="numberOfBridgeInterfaces", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="number_of_containers", remote_name="numberOfContainers", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="number_of_host_interfaces", remote_name="numberOfHostInterfaces", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="number_of_virtual_machines", remote_name="numberOfVirtualMachines", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="current_cpuusage", remote_name="currentCPUUsage", attribute_type=float, is_required=False, is_unique=False)
@@ -242,6 +279,9 @@ class NUVRS(NURESTObject):
         self.monitoring_ports = NUMonitoringPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.containers = NUContainersFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.vports = NUVPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -696,6 +736,141 @@ class NUVRS(NURESTObject):
         self._messages = value
 
     
+    @property
+    def revert_behavior_enabled(self):
+        """ Get revert_behavior_enabled value.
+
+            Notes:
+                Flag to indicate if the revert behavior took place or not.
+
+                
+                This attribute is named `revertBehaviorEnabled` in VSD API.
+                
+        """
+        return self._revert_behavior_enabled
+
+    @revert_behavior_enabled.setter
+    def revert_behavior_enabled(self, value):
+        """ Set revert_behavior_enabled value.
+
+            Notes:
+                Flag to indicate if the revert behavior took place or not.
+
+                
+                This attribute is named `revertBehaviorEnabled` in VSD API.
+                
+        """
+        self._revert_behavior_enabled = value
+
+    
+    @property
+    def revert_completed(self):
+        """ Get revert_completed value.
+
+            Notes:
+                Flag indicates whether revert was completed successfully.
+
+                
+                This attribute is named `revertCompleted` in VSD API.
+                
+        """
+        return self._revert_completed
+
+    @revert_completed.setter
+    def revert_completed(self, value):
+        """ Set revert_completed value.
+
+            Notes:
+                Flag indicates whether revert was completed successfully.
+
+                
+                This attribute is named `revertCompleted` in VSD API.
+                
+        """
+        self._revert_completed = value
+
+    
+    @property
+    def revert_count(self):
+        """ Get revert_count value.
+
+            Notes:
+                Indicates the number of retries for the revert to take place.
+
+                
+                This attribute is named `revertCount` in VSD API.
+                
+        """
+        return self._revert_count
+
+    @revert_count.setter
+    def revert_count(self, value):
+        """ Set revert_count value.
+
+            Notes:
+                Indicates the number of retries for the revert to take place.
+
+                
+                This attribute is named `revertCount` in VSD API.
+                
+        """
+        self._revert_count = value
+
+    
+    @property
+    def revert_failed_count(self):
+        """ Get revert_failed_count value.
+
+            Notes:
+                This value indicates the number of failed attempts for the revert to happen successfully.
+
+                
+                This attribute is named `revertFailedCount` in VSD API.
+                
+        """
+        return self._revert_failed_count
+
+    @revert_failed_count.setter
+    def revert_failed_count(self, value):
+        """ Set revert_failed_count value.
+
+            Notes:
+                This value indicates the number of failed attempts for the revert to happen successfully.
+
+                
+                This attribute is named `revertFailedCount` in VSD API.
+                
+        """
+        self._revert_failed_count = value
+
+    
+    @property
+    def licensed_state(self):
+        """ Get licensed_state value.
+
+            Notes:
+                Licensed state.
+
+                
+                This attribute is named `licensedState` in VSD API.
+                
+        """
+        return self._licensed_state
+
+    @licensed_state.setter
+    def licensed_state(self, value):
+        """ Set licensed_state value.
+
+            Notes:
+                Licensed state.
+
+                
+                This attribute is named `licensedState` in VSD API.
+                
+        """
+        self._licensed_state = value
+
+    
     @property
     def disks(self):
         """ Get disks value.
@@ -842,6 +1017,33 @@ class NUVRS(NURESTObject):
         self._uptime = value
 
     
+    @property
+    def primary_vsc_connection_lost(self):
+        """ Get primary_vsc_connection_lost value.
+
+            Notes:
+                Flag indicates whether the connection with the primary is lost, which will help trigger alarms.
+
+                
+                This attribute is named `primaryVSCConnectionLost` in VSD API.
+                
+        """
+        return self._primary_vsc_connection_lost
+
+    @primary_vsc_connection_lost.setter
+    def primary_vsc_connection_lost(self, value):
+        """ Set primary_vsc_connection_lost value.
+
+            Notes:
+                Flag indicates whether the connection with the primary is lost, which will help trigger alarms.
+
+                
+                This attribute is named `primaryVSCConnectionLost` in VSD API.
+                
+        """
+        self._primary_vsc_connection_lost = value
+
+    
     @property
     def product_version(self):
         """ Get product_version value.
@@ -896,6 +1098,60 @@ class NUVRS(NURESTObject):
         self._is_resilient = value
 
     
+    @property
+    def vsc_config_state(self):
+        """ Get vsc_config_state value.
+
+            Notes:
+                Indicates the configured state of the VSC.
+
+                
+                This attribute is named `vscConfigState` in VSD API.
+                
+        """
+        return self._vsc_config_state
+
+    @vsc_config_state.setter
+    def vsc_config_state(self, value):
+        """ Set vsc_config_state value.
+
+            Notes:
+                Indicates the configured state of the VSC.
+
+                
+                This attribute is named `vscConfigState` in VSD API.
+                
+        """
+        self._vsc_config_state = value
+
+    
+    @property
+    def vsc_current_state(self):
+        """ Get vsc_current_state value.
+
+            Notes:
+                Indicates the current state of the VSC, which may or maybe not be same as the configured state.
+
+                
+                This attribute is named `vscCurrentState` in VSD API.
+                
+        """
+        return self._vsc_current_state
+
+    @vsc_current_state.setter
+    def vsc_current_state(self, value):
+        """ Set vsc_current_state value.
+
+            Notes:
+                Indicates the current state of the VSC, which may or maybe not be same as the configured state.
+
+                
+                This attribute is named `vscCurrentState` in VSD API.
+                
+        """
+        self._vsc_current_state = value
+
+    
     @property
     def status(self):
         """ Get status value.
@@ -973,6 +1229,33 @@ class NUVRS(NURESTObject):
         self._number_of_bridge_interfaces = value
 
     
+    @property
+    def number_of_containers(self):
+        """ Get number_of_containers value.
+
+            Notes:
+                Number of containers defined in this VRS.
+
+                
+                This attribute is named `numberOfContainers` in VSD API.
+                
+        """
+        return self._number_of_containers
+
+    @number_of_containers.setter
+    def number_of_containers(self, value):
+        """ Set number_of_containers value.
+
+            Notes:
+                Number of containers defined in this VRS.
+
+                
+                This attribute is named `numberOfContainers` in VSD API.
+                
+        """
+        self._number_of_containers = value
+
+    
     @property
     def number_of_host_interfaces(self):
         """ Get number_of_host_interfaces value.
