@@ -104,6 +104,7 @@ class NUZoneTemplate(NURESTObject):
         
         self._dpi = None
         self._ip_type = None
+        self._ipv6_address = None
         self._name = None
         self._last_updated_by = None
         self._address = None
@@ -116,9 +117,11 @@ class NUZoneTemplate(NURESTObject):
         self._multicast = None
         self._number_of_hosts_in_subnets = None
         self._external_id = None
+        self._dynamic_ipv6_address = None
         
         self.expose_attribute(local_name="dpi", remote_name="DPI", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="ip_type", remote_name="IPType", attribute_type=str, is_required=False, is_unique=False, choices=[u'IPV4', u'IPV6'])
+        self.expose_attribute(local_name="ipv6_address", remote_name="IPv6Address", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=False, is_unique=False)
@@ -131,6 +134,7 @@ class NUZoneTemplate(NURESTObject):
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="number_of_hosts_in_subnets", remote_name="numberOfHostsInSubnets", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
+        self.expose_attribute(local_name="dynamic_ipv6_address", remote_name="dynamicIpv6Address", attribute_type=bool, is_required=False, is_unique=False)
         
 
         # Fetchers
@@ -209,6 +213,33 @@ class NUZoneTemplate(NURESTObject):
         self._ip_type = value
 
     
+    @property
+    def ipv6_address(self):
+        """ Get ipv6_address value.
+
+            Notes:
+                IPv6 address range of the zone. This is an optional field that allows users to allocate an address range to a zone. The VSD will auto-assign IP ranges to subnets from this range if an IP range is not defined for a subnet.
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        return self._ipv6_address
+
+    @ipv6_address.setter
+    def ipv6_address(self, value):
+        """ Set ipv6_address value.
+
+            Notes:
+                IPv6 address range of the zone. This is an optional field that allows users to allocate an address range to a zone. The VSD will auto-assign IP ranges to subnets from this range if an IP range is not defined for a subnet.
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        self._ipv6_address = value
+
+    
     @property
     def name(self):
         """ Get name value.
@@ -264,7 +295,7 @@ class NUZoneTemplate(NURESTObject):
         """ Get address value.
 
             Notes:
-                IP address of the subnet defined. In case of zone, this is an optional field for and allows users to allocate an IP address range to a zone. The VSD will auto-assign IP addresses to subnets from this range if a specific IP address is not defined for the subnet
+                IPv4 address range of the zone. This is an optional field that allows users to allocate an address range to a zone. The VSD will auto-assign IP ranges to subnets from this range if an IP range is not defined for a subnet.
 
                 
         """
@@ -275,7 +306,7 @@ class NUZoneTemplate(NURESTObject):
         """ Set address value.
 
             Notes:
-                IP address of the subnet defined. In case of zone, this is an optional field for and allows users to allocate an IP address range to a zone. The VSD will auto-assign IP addresses to subnets from this range if a specific IP address is not defined for the subnet
+                IPv4 address range of the zone. This is an optional field that allows users to allocate an address range to a zone. The VSD will auto-assign IP ranges to subnets from this range if an IP range is not defined for a subnet.
 
                 
         """
@@ -509,6 +540,33 @@ class NUZoneTemplate(NURESTObject):
         self._external_id = value
 
     
+    @property
+    def dynamic_ipv6_address(self):
+        """ Get dynamic_ipv6_address value.
+
+            Notes:
+                Turn on or off dynamic allocation of IPV6 address
+
+                
+                This attribute is named `dynamicIpv6Address` in VSD API.
+                
+        """
+        return self._dynamic_ipv6_address
+
+    @dynamic_ipv6_address.setter
+    def dynamic_ipv6_address(self, value):
+        """ Set dynamic_ipv6_address value.
+
+            Notes:
+                Turn on or off dynamic allocation of IPV6 address
+
+                
+                This attribute is named `dynamicIpv6Address` in VSD API.
+                
+        """
+        self._dynamic_ipv6_address = value
+
+    
 
     
     ## Custom methods
